@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp.c,v 1.77 2003/04/16 19:36:15 mike Exp $"
+ * "$Id: ipp.c,v 1.79 2003/10/09 19:13:27 mike Exp $"
  *
  *   IPP backend for the Common UNIX Printing System (CUPS).
  *
@@ -43,6 +43,7 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <cups/http-private.h>
 #include <cups/cups.h>
 #include <cups/language.h>
 #include <cups/string.h>
@@ -55,39 +56,9 @@
  */
 
 static char	tmpfilename[1024] = "";	/* Temporary spool file name */
-
-
-/*
- * Some OS's don't have hstrerror(), most notably Solaris...
- */
-
-#ifndef HAVE_HSTRERROR
-#  define hstrerror cups_hstrerror
-
-const char *					/* O - Error string */
-cups_hstrerror(int error)			/* I - Error number */
-{
-  static const char * const errors[] =
-		{
-		  "OK",
-		  "Host not found.",
-		  "Try again.",
-		  "Unrecoverable lookup error.",
-		  "No data associated with name."
-		};
-
-
-  if (error < 0 || error > 4)
-    return ("Unknown hostname lookup error.");
-  else
-    return (errors[error]);
-}
-#elif defined(_AIX)
-/*
- * AIX doesn't provide a prototype but does provide the function...
- */
-extern const char *hstrerror(int);
-#endif /* !HAVE_HSTRERROR */
+#ifdef __APPLE__
+static char	pstmpname[1024] = "";	/* Temporary PostScript file name */
+#endif /* __APPLE__ */
 
 
 /*
@@ -98,7 +69,7 @@ const char	*password_cb(const char *);
 int		report_printer_state(ipp_t *ipp);
 
 #ifdef __APPLE__
-int		run_pictwps_filter(char **argv, char *filename, int length);
+int		run_pictwps_filter(char **argv, const char *filename);
 #endif /* __APPLE__ */
 static void	sigterm_handler(int sig);
 
@@ -633,9 +604,11 @@ main(int  argc,		/* I - Number of command-line arguments (6 or 7) */
 	* so convert the document to PostScript...
 	*/
 
-	if (run_pictwps_filter(argv, filename, sizeof(filename)))
+	if (run_pictwps_filter(argv, filename))
 	  return (1);
 
+        filename = pstmpname;
+
        /*
 	* Change the MIME type to application/postscript...
 	*/
@@ -892,12 +865,17 @@ main(int  argc,		/* I - Number of command-line arguments (6 or 7) */
     ippDelete(supported);
 
  /*
-  * Remove the temporary file if necessary...
+  * Remove the temporary file(s) if necessary...
   */
 
   if (tmpfilename[0])
     unlink(tmpfilename);
 
+#ifdef __APPLE__
+  if (pstmpname[0])
+    unlink(pstmpname);
+#endif /* __APPLE__ */
+
  /*
   * Return the queue status...
   */
@@ -1045,9 +1023,8 @@ report_printer_state(ipp_t *ipp)	/* I - IPP response */
  */
 
 int						/* O - Exit status of filter */
-run_pictwps_filter(char **argv,			/* I - Command-line arguments */
-                   char *filename,		/* I - Filename buffer */
-		   int  length)			/* I - Size of filename buffer */
+run_pictwps_filter(char       **argv,		/* I - Command-line arguments */
+                   const char *filename)	/* I - Filename */
 {
   struct stat	fileinfo;			/* Print file information */
   const char	*ppdfile;			/* PPD file for destination printer */
@@ -1085,7 +1062,7 @@ run_pictwps_filter(char **argv,			/* I - Command-line arguments */
   * Then create a temporary file for printing...
   */
 
-  if ((fd = cupsTempFd(filename, length)) < 0)
+  if ((fd = cupsTempFd(pstmpname, sizeof(pstmpname))) < 0)
   {
     fprintf(stderr, "ERROR: Unable to create temporary file - %s.\n",
             strerror(errno));
@@ -1099,7 +1076,18 @@ run_pictwps_filter(char **argv,			/* I - Command-line arguments */
   * as...
   */
 
-  stat(argv[6], &fileinfo);
+  if (argv[6])
+    stat(argv[6], &fileinfo);
+  else
+  {
+   /*
+    * Use the OSX defaults, as an up-stream filter created the PICT
+    * file...
+    */
+
+    fileinfo.st_uid = 1;
+    fileinfo.st_gid = 80;
+  }
 
   if (ppdfile)
     chown(ppdfile, fileinfo.st_uid, fileinfo.st_gid);
@@ -1132,7 +1120,7 @@ run_pictwps_filter(char **argv,			/* I - Command-line arguments */
     }
 
     execlp("pictwpstops", printer, argv[1], argv[2], argv[3], argv[4], argv[5],
-           argv[6], NULL);
+           filename, NULL);
     perror("ERROR: Unable to exec pictwpstops");
     return (errno);
   }
@@ -1203,16 +1191,21 @@ sigterm_handler(int sig)		/* I - Signal */
   (void)sig;	/* remove compiler warnings... */
 
  /*
-  * Remove the temporary file if necessary...
+  * Remove the temporary file(s) if necessary...
   */
 
   if (tmpfilename[0])
     unlink(tmpfilename);
 
+#ifdef __APPLE__
+  if (pstmpname[0])
+    unlink(pstmpname);
+#endif /* __APPLE__ */
+
   exit(1);
 }
 
 
 /*
- * End of "$Id: ipp.c,v 1.77 2003/04/16 19:36:15 mike Exp $".
+ * End of "$Id: ipp.c,v 1.79 2003/10/09 19:13:27 mike Exp $".
  */
