@@ -1,5 +1,5 @@
 /*
- * "$Id: lpd.c,v 1.51 2003/04/10 12:57:40 mike Exp $"
+ * "$Id: lpd.c,v 1.56 2003/11/19 18:58:04 mike Exp $"
  *
  *   Line Printer Daemon backend for the Common UNIX Printing System (CUPS).
  *
@@ -43,6 +43,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
+#include <cups/http-private.h>
 #include <cups/string.h>
 #include <errno.h>
 #include <sys/types.h>
@@ -66,39 +67,6 @@
 static char	tmpfilename[1024] = "";	/* Temporary spool file name */
 
 
-/*
- * Some OS's don't have hstrerror(), most notably Solaris...
- */
-
-#ifndef HAVE_HSTRERROR
-#  define hstrerror cups_hstrerror
-
-const char *					/* O - Error string */
-cups_hstrerror(int error)			/* I - Error number */
-{
-  static const char * const errors[] =
-		{
-		  "OK",
-		  "Host not found.",
-		  "Try again.",
-		  "Unrecoverable lookup error.",
-		  "No data associated with name."
-		};
-
-
-  if (error < 0 || error > 4)
-    return ("Unknown hostname lookup error.");
-  else
-    return (errors[error]);
-}
-#elif defined(_AIX)
-/*
- * AIX doesn't provide a prototype but does provide the function...
- */
-extern const char *hstrerror(int);
-#endif /* !HAVE_HSTRERROR */
-
-
 /*
  * The order for control and data files in LPD requests...
  */
@@ -119,8 +87,9 @@ extern int	rresvport(int *port);
  */
 
 static int	lpd_command(int lpd_fd, int timeout, char *format, ...);
-static int	lpd_queue(char *hostname, char *printer, char *filename,
-		          char *user, char *title, int copies,
+static int	lpd_queue(const char *hostname, int port, const char *printer,
+		          const char *filename,
+		          const char *user, const char *title, int copies,
 			  int banner, int format, int order, int reserve,
 			  int manual_copies, int timeout);
 static void	lpd_timeout(int sig);
@@ -150,7 +119,7 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
 			*ptr,		/* Pointer into name or value */
 			*filename,	/* File to print */
 			title[256];	/* Title string */
-  int			port;		/* Port number (not used) */
+  int			port;		/* Port number */
   int			status;		/* Status of LPD job */
   int			banner;		/* Print banner page? */
   int			format;		/* Print format */
@@ -424,7 +393,7 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
       copies        = atoi(argv[4]);
     }
 
-    status = lpd_queue(hostname, resource + 1, filename,
+    status = lpd_queue(hostname, port, resource + 1, filename,
                        argv[2] /* user */, title, copies,
 		       banner, format, order, reserve, manual_copies, timeout);
 
@@ -432,7 +401,7 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
       fprintf(stderr, "PAGE: 1 %d\n", atoi(argv[4]));
   }
   else
-    status = lpd_queue(hostname, resource + 1, filename,
+    status = lpd_queue(hostname, port, resource + 1, filename,
                        argv[2] /* user */, title, 1,
 		       banner, format, order, reserve, 1, timeout);
 
@@ -517,24 +486,25 @@ lpd_command(int  fd,		/* I - Socket connection to LPD host */
  */
 
 static int				/* O - Zero on success, non-zero on failure */
-lpd_queue(char *hostname,		/* I - Host to connect to */
-          char *printer,		/* I - Printer/queue name */
-	  char *filename,		/* I - File to print */
-          char *user,			/* I - Requesting user */
-	  char *title,			/* I - Job title */
-	  int  copies,			/* I - Number of copies */
-	  int  banner,			/* I - Print LPD banner? */
-          int  format,			/* I - Format specifier */
-          int  order,			/* I - Order of data/control files */
-	  int  reserve,			/* I - Reserve ports? */
-	  int  manual_copies,		/* I - Do copies by hand... */
-	  int  timeout)			/* I - Timeout... */
+lpd_queue(const char *hostname,		/* I - Host to connect to */
+          int        port,		/* I - Port to connect on */
+          const char *printer,		/* I - Printer/queue name */
+	  const char *filename,		/* I - File to print */
+          const char *user,		/* I - Requesting user */
+	  const char *title,		/* I - Job title */
+	  int        copies,		/* I - Number of copies */
+	  int        banner,		/* I - Print LPD banner? */
+          int        format,		/* I - Format specifier */
+          int        order,		/* I - Order of data/control files */
+	  int        reserve,		/* I - Reserve ports? */
+	  int        manual_copies,	/* I - Do copies by hand... */
+	  int        timeout)		/* I - Timeout... */
 {
   FILE			*fp;		/* Job file */
   char			localhost[255];	/* Local host name */
   int			error;		/* Error number */
   struct stat		filestats;	/* File statistics */
-  int			port;		/* LPD connection port */
+  int			lport;		/* LPD connection local port */
   int			fd;		/* LPD socket */
   char			control[10240],	/* LPD control 'file' */
 			*cptr;		/* Pointer into control file string */
@@ -589,9 +559,9 @@ lpd_queue(char *hostname,		/* I - Host to connect to */
     memset(&addr, 0, sizeof(addr));
     memcpy(&(addr.sin_addr), hostaddr->h_addr, hostaddr->h_length);
     addr.sin_family = hostaddr->h_addrtype;
-    addr.sin_port   = htons(515);	/* LPD/printer service */
+    addr.sin_port   = htons(port);
 
-    for (port = 732;;)
+    for (lport = 732;;)
     {
       if (getuid() || !reserve)
       {
@@ -605,16 +575,16 @@ lpd_queue(char *hostname,		/* I - Host to connect to */
           return (1);
 	}
 
-	port = 515;
+        lport = 0;
       }
       else
       {
        /*
 	* We're running as root and want to comply with RFC 1179.  Reserve a
-	* priviledged port between 721 and 732...
+	* priviledged lport between 721 and 732...
 	*/
 
-	if ((fd = rresvport(&port)) < 0)
+	if ((fd = rresvport(&lport)) < 0)
 	{
 	  perror("ERROR: Unable to reserve port");
 	  sleep(30);
@@ -651,7 +621,9 @@ lpd_queue(char *hostname,		/* I - Host to connect to */
 	break;
     }
 
-    fprintf(stderr, "INFO: Connected from port %d...\n", port);
+    fprintf(stderr, "INFO: Connected to %s...\n", hostname);
+    fprintf(stderr, "DEBUG: Connected on ports %d (local %d)...\n", port,
+            lport);
 
    /*
     * Next, open the print file and figure out its size...
@@ -683,12 +655,14 @@ lpd_queue(char *hostname,		/* I - Host to connect to */
     gethostname(localhost, sizeof(localhost));
     localhost[31] = '\0'; /* RFC 1179, Section 7.2 - host name < 32 chars */
 
-    snprintf(control, sizeof(control), "H%s\nP%s\nJ%s\n", localhost, user, title);
+    snprintf(control, sizeof(control), "H%s\nP%s\nJ%s\n", localhost, user,
+             title);
     cptr = control + strlen(control);
 
     if (banner)
     {
-      snprintf(cptr, sizeof(control) - (cptr - control), "L%s\n", user);
+      snprintf(cptr, sizeof(control) - (cptr - control), "C%s\nL%s\n",
+               localhost, user);
       cptr   += strlen(cptr);
     }
 
@@ -1020,5 +994,5 @@ sigterm_handler(int sig)		/* I - Signal */
 
 
 /*
- * End of "$Id: lpd.c,v 1.51 2003/04/10 12:57:40 mike Exp $".
+ * End of "$Id: lpd.c,v 1.56 2003/11/19 18:58:04 mike Exp $".
  */
