@@ -1,5 +1,5 @@
 /*
- * "$Id: parallel.c,v 1.45 2002/12/17 18:56:33 swdev Exp $"
+ * "$Id: parallel.c,v 1.46 2003/08/30 23:12:09 mike Exp $"
  *
  *   Parallel port backend for the Common UNIX Printing System (CUPS).
  *
@@ -281,6 +281,9 @@ main(int  argc,		/* I - Number of command-line arguments (6 or 7) */
 	bufptr += wbytes;
       }
 
+      if (wbytes < 0)
+        break;
+
       if (argc > 6)
 	fprintf(stderr, "INFO: Sending print file, %lu bytes...\n",
 	        (unsigned long)tbytes);
@@ -672,5 +675,5 @@ list_devices(void)
 
 
 /*
- * End of "$Id: parallel.c,v 1.45 2002/12/17 18:56:33 swdev Exp $".
+ * End of "$Id: parallel.c,v 1.46 2003/08/30 23:12:09 mike Exp $".
  */
