@@ -1,5 +1,5 @@
 /*
- * "$Id: usb.c,v 1.44 2003/01/27 17:12:08 mike Exp $"
+ * "$Id: usb.c,v 1.49 2003/09/02 20:19:17 mike Exp $"
  *
  *   USB port backend for the Common UNIX Printing System (CUPS).
  *
@@ -230,26 +230,30 @@ main(int  argc,		/* I - Number of command-line arguments (6 or 7) */
 #endif /* HAVE_SIGSET */
   }
 
-#ifdef __linux
+#if defined(__linux) && defined(LP_POUTPA)
  /*
   * Show the printer status before we send the file; normally, we'd
   * do this while we write data to the printer, however at least some
   * Linux kernels have buggy USB drivers which don't like to be
   * queried while sending data to the printer...
+  *
+  * Also, we're using the 8255 constants instead of the ones that are
+  * supposed to be used, as it appears that the USB driver also doesn't
+  * follow standards...
   */
 
   if (ioctl(fd, LPGETSTATUS, &status) == 0)
   {
     fprintf(stderr, "DEBUG: LPGETSTATUS returned a port status of %02X...\n", status);
 
-    if (status & LP_NOPA)
+    if (!(status & LP_POUTPA))
       fputs("WARNING: Media tray empty!\n", stderr);
-    else if (status & LP_ERR)
+    else if (!(status & LP_PERRORP))
       fputs("WARNING: Printer fault!\n", stderr);
-    else if (status & LP_OFFL)
+    else if (!(status & LP_PSELECD))
       fputs("WARNING: Printer off-line.\n", stderr);
   }
-#endif /* __linux */
+#endif /* __linux && LP_POUTPA */
 
  /*
   * Finally, send the print file...
@@ -292,6 +296,9 @@ main(int  argc,		/* I - Number of command-line arguments (6 or 7) */
 	bufptr += wbytes;
       }
 
+      if (wbytes < 0)
+        break;
+
       if (argc > 6)
 	fprintf(stderr, "INFO: Sending print file, %lu bytes...\n",
 	        (unsigned long)tbytes);
@@ -327,6 +334,8 @@ decode_device_id(int        port,		/* I - Port number */
   char	*attr,					/* 1284 attribute */
   	*delim,					/* 1284 delimiter */
 	*uriptr,				/* Pointer into URI */
+	*mfg,					/* Manufacturer string */
+	*mdl,					/* Model string */
 	serial_number[1024];			/* Serial number string */
 
 
@@ -339,6 +348,16 @@ decode_device_id(int        port,		/* I - Port number */
   else if ((attr = strstr(device_id, "DESCRIPTION:")) != NULL)
     attr += 12;
 
+  if ((mfg = strstr(device_id, "MANUFACTURER:")) != NULL)
+    mfg += 13;
+  else if ((mfg = strstr(device_id, "MFG:")) != NULL)
+    mfg += 4;
+
+  if ((mdl = strstr(device_id, "MODEL:")) != NULL)
+    mdl += 6;
+  else if ((mdl = strstr(device_id, "MDL:")) != NULL)
+    mdl += 4;
+
   if (attr)
   {
     if (strncasecmp(attr, "Hewlett-Packard ", 16) == 0)
@@ -354,8 +373,31 @@ decode_device_id(int        port,		/* I - Port number */
     if ((delim = strchr(make_model, ';')) != NULL)
       *delim = '\0';
   }
+  else if (mfg && mdl)
+  {
+   /*
+    * Build a make-model string from the manufacturer and model attributes...
+    */
+
+    strlcpy(make_model, mfg, mmsize);
+
+    if ((delim = strchr(make_model, ';')) != NULL)
+      *delim = '\0';
+
+    strlcat(make_model, " ", mmsize);
+    strlcat(make_model, mdl, mmsize);
+
+    if ((delim = strchr(make_model, ';')) != NULL)
+      *delim = '\0';
+  }
   else
+  {
+   /*
+    * Use "Unknown" as the printer make and model...
+    */
+
     strlcpy(make_model, "Unknown", mmsize);
+  }
 
  /*
   * Look for the serial number field...
@@ -474,7 +516,7 @@ list_devices(void)
         if (length > (sizeof(device_id) - 2))
 	  length = sizeof(device_id) - 2;
 
-	memcpy(device_id, device_id + 2, length);
+	memmove(device_id, device_id + 2, length);
 	device_id[length] = '\0';
       }
       else
@@ -633,7 +675,7 @@ open_device(const char *uri)		/* I - Device URI */
 	{
 	  length = (((unsigned)device_id[0] & 255) << 8) +
 	           ((unsigned)device_id[1] & 255);
-	  memcpy(device_id, device_id + 2, length);
+	  memmove(device_id, device_id + 2, length);
 	  device_id[length] = '\0';
 	}
 	else
@@ -652,7 +694,15 @@ open_device(const char *uri)		/* I - Device URI */
                 	 device_uri, sizeof(device_uri));
 
         if (strcmp(uri, device_uri) == 0)
-	  return (fd);	/* Yes, return this file descriptor... */
+	{
+	 /*
+	  * Yes, return this file descriptor...
+	  */
+
+	  fprintf(stderr, "DEBUG: Printer using device file \"%s\"...\n", device);
+
+	  return (fd);
+	}
       }
 
      /*
@@ -752,5 +802,5 @@ open_device(const char *uri)		/* I - Device URI */
 
 
 /*
- * End of "$Id: usb.c,v 1.44 2003/01/27 17:12:08 mike Exp $".
+ * End of "$Id: usb.c,v 1.49 2003/09/02 20:19:17 mike Exp $".
  */
