@@ -1,5 +1,5 @@
 /*
- * "$Id: lpq.c,v 1.23 2002/12/17 18:56:35 swdev Exp $"
+ * "$Id: lpq.c,v 1.26 2003/05/22 12:48:13 mike Exp $"
  *
  *   "lpq" command for the Common UNIX Printing System (CUPS).
  *
@@ -26,6 +26,7 @@
  *   main()         - Parse options and commands.
  *   show_jobs()    - Show jobs.
  *   show_printer() - Show printer status.
+ *   usage()        - Show program usage.
  */
 
 /*
@@ -51,6 +52,7 @@
 static int	show_jobs(http_t *, const char *, const char *, const int,
 		          const int);
 static void	show_printer(http_t *, const char *);
+static void	usage(void);
 
 
 /*
@@ -71,9 +73,9 @@ main(int  argc,		/* I - Number of command-line arguments */
 		longstatus;	/* Show file details */
   int		num_dests;	/* Number of destinations */
   cups_dest_t	*dests;		/* Destinations */
-#ifdef HAVE_LIBSSL
+#ifdef HAVE_SSL
   http_encryption_t encryption;	/* Encryption? */
-#endif /* HAVE_LIBSSL */
+#endif /* HAVE_SSL */
 
 
  /*
@@ -111,7 +113,7 @@ main(int  argc,		/* I - Number of command-line arguments */
       switch (argv[i][1])
       {
         case 'E' : /* Encrypt */
-#ifdef HAVE_LIBSSL
+#ifdef HAVE_SSL
 	    encryption = HTTP_ENCRYPT_REQUIRED;
 
 	    if (http)
@@ -119,7 +121,7 @@ main(int  argc,		/* I - Number of command-line arguments */
 #else
             fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
 	            argv[0]);
-#endif /* HAVE_LIBSSL */
+#endif /* HAVE_SSL */
 	    break;
 
         case 'P' : /* Printer */
@@ -128,6 +130,15 @@ main(int  argc,		/* I - Number of command-line arguments */
 	    else
 	    {
 	      i ++;
+
+	      if (i >= argc)
+	      {
+		httpClose(http);
+		cupsFreeDests(num_dests, dests);
+	        
+	        usage();
+	      }
+
 	      dest = argv[i];
 	    }
 
@@ -155,10 +166,11 @@ main(int  argc,		/* I - Number of command-line arguments */
 	    break;
 
 	default :
-	    fputs("Usage: lpq [-P dest] [-l] [+interval]\n", stderr);
 	    httpClose(http);
-            cupsFreeDests(num_dests, dests);
-	    return (1);
+	    cupsFreeDests(num_dests, dests);
+
+	    usage();
+	    break;
       }
     }
     else if (isdigit(argv[i][0]))
@@ -427,15 +439,15 @@ show_jobs(http_t     *http,	/* I - HTTP connection to server */
 	else
 	  strlcpy(namestr, jobname, sizeof(namestr));
 
-        printf("%s: %-34.34s[job %d localhost]\n", jobuser, rankstr, jobid);
-        printf("        %-40.40s%d bytes\n", namestr, jobsize);
+        printf("%s: %-33.33s [job %d localhost]\n", jobuser, rankstr, jobid);
+        printf("        %-39.39s %d bytes\n", namestr, jobsize);
       }
       else
 #ifdef __osf__
         printf("%-6s %-10.10s %-4d %-10d %-27.27s %d bytes\n", rankstr, jobuser,
 	       jobpriority, jobid, jobname, jobsize);
 #else
-        printf("%-7s %-8.8s%-8d%-32.32s%d bytes\n", rankstr, jobuser,
+        printf("%-7s %-7.7s %-7d %-31.31s %d bytes\n", rankstr, jobuser,
 	       jobid, jobname, jobsize);
 #endif /* __osf */
 
@@ -545,5 +557,17 @@ show_printer(http_t     *http,	/* I - HTTP connection to server */
 
 
 /*
- * End of "$Id: lpq.c,v 1.23 2002/12/17 18:56:35 swdev Exp $".
+ * 'usage()' - Show program usage.
+ */
+
+static void
+usage(void)
+{
+  fputs("Usage: lpq [-P dest] [-l] [+interval]\n", stderr);
+  exit(1);
+}
+
+
+/*
+ * End of "$Id: lpq.c,v 1.26 2003/05/22 12:48:13 mike Exp $".
  */
