@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp-var.c,v 1.34 2003/04/08 03:45:14 mike Exp $"
+ * "$Id: ipp-var.c,v 1.40 2003/11/07 18:52:38 mike Exp $"
  *
  *   IPP variable routines for the Common UNIX Printing System (CUPS).
  *
@@ -23,7 +23,10 @@
  *
  * Contents:
  *
+ *   ippGetAttributes()    - Get the list of attributes that are needed
+ *                           by the template file.
  *   ippGetTemplateDir()   - Get the templates directory...
+ *   ippRewriteURL()       - Rewrite a printer URI into a web browser URL...
  *   ippSetServerVersion() - Set the server name and CUPS version...
  *   ippSetCGIVars()       - Set CGI variables from an IPP response.
  */
@@ -35,6 +38,127 @@
 #include "ipp-var.h"
 
 
+/*
+ * 'ippGetAttributes()' - Get the list of attributes that are needed
+ *                        by the template file.
+ */
+
+void
+ippGetAttributes(ipp_t      *request,	/* I - IPP request */
+                 const char *directory,	/* I - Directory */
+		 const char *tmpl,	/* I - Base filename */
+		 const char *lang)	/* I - Language */
+{
+  int	num_attrs;			/* Number of attributes */
+  char	*attrs[1000];			/* Attributes */
+  int	i;				/* Looping var */
+  char	filename[1024],			/* Filename */
+	locale[16];			/* Locale name */
+  FILE	*in;				/* Input file */
+  int	ch;				/* Character from file */
+  char	name[255],			/* Name of variable */
+	*nameptr;			/* Pointer into name */
+
+
+ /*
+  * Convert the language to a locale name...
+  */
+
+  if (lang != NULL)
+  {
+    for (i = 0; lang[i] && i < 15; i ++)
+      if (isalnum(lang[i]))
+        locale[i] = tolower(lang[i]);
+      else
+        locale[i] = '_';
+
+    locale[i] = '\0';
+  }
+  else
+    locale[0] = '\0';
+
+ /*
+  * See if we have a template file for this language...
+  */
+
+  snprintf(filename, sizeof(filename), "%s/%s/%s", directory, locale, tmpl);
+  if (access(filename, 0))
+  {
+    locale[2] = '\0';
+
+    snprintf(filename, sizeof(filename), "%s/%s/%s", directory, locale, tmpl);
+    if (access(filename, 0))
+      snprintf(filename, sizeof(filename), "%s/%s", directory, tmpl);
+  }
+
+ /*
+  * Open the template file...
+  */
+
+  if ((in = fopen(filename, "r")) == NULL)
+    return;
+
+ /*
+  * Loop through the file adding attribute names as needed...
+  */
+
+  num_attrs = 0;
+
+  while ((ch = getc(in)) != EOF)
+    if (ch == '\\')
+      getc(in);
+    else if (ch == '{' && num_attrs < (sizeof(attrs) / sizeof(attrs[0])))
+    {
+     /*
+      * Grab the name...
+      */
+
+      for (nameptr = name; (ch = getc(in)) != EOF;)
+        if (strchr("}]<>=! \t\n", ch))
+          break;
+        else if (nameptr > name && ch == '?')
+	  break;
+	else if (nameptr < (name + sizeof(name) - 1))
+	{
+	  if (ch == '_')
+	    *nameptr++ = '-';
+	  else
+            *nameptr++ = ch;
+	}
+
+      *nameptr = '\0';
+
+     /*
+      * Possibly add it to the list of attributes...
+      */
+
+      for (i = 0; i < num_attrs; i ++)
+        if (!strcmp(attrs[i], name))
+	  break;
+
+      if (i >= num_attrs)
+      {
+	attrs[num_attrs] = strdup(name);
+	num_attrs ++;
+      }
+    }
+
+ /*
+  * If we have attributes, add a requested-attributes attribute to the
+  * request...
+  */
+
+  if (num_attrs > 0)
+  {
+    ippAddStrings(request, IPP_TAG_OPERATION, IPP_TAG_KEYWORD,
+                  "requested-attributes", num_attrs, NULL, (const char **)attrs);
+
+    for (i = 0; i < num_attrs; i ++)
+      free(attrs[i]);
+  }
+}
+
+
 /*
  * 'ippGetTemplateDir()' - Get the templates directory...
  */
@@ -62,6 +186,123 @@ ippGetTemplateDir(void)
 }
 
 
+/*
+ * 'ippRewriteURL()' - Rewrite a printer URI into a web browser URL...
+ */
+
+char *					/* O - New URL */
+ippRewriteURL(const char *uri,		/* I - Current URI */
+              char       *url,		/* O - New URL */
+	      int        urlsize)	/* I - Size of URL buffer */
+{
+  char			method[HTTP_MAX_URI],
+			userpass[HTTP_MAX_URI],
+			hostname[HTTP_MAX_URI],
+			rawresource[HTTP_MAX_URI],
+			resource[HTTP_MAX_URI],
+					/* URI components... */
+			*rawptr,	/* Pointer into rawresource */
+			*resptr;	/* Pointer into resource */
+  int			port;		/* Port number */
+  static int		ishttps = -1;	/* Using encryption? */
+  static const char	*server;	/* Name of server */
+  static char		servername[1024];
+					/* Local server name */
+  static const char	hexchars[] = "0123456789ABCDEF";
+					/* Hexadecimal conversion characters */
+
+
+ /*
+  * Check if we have been called before...
+  */
+
+  if (ishttps < 0)
+  {
+   /*
+    * No, initialize static vars for the conversion...
+    *
+    * First get the server name associated with the client interface as
+    * well as the locally configured hostname.  We'll check *both* of
+    * these to see if the printer URL is local...
+    */
+
+    server = getenv("SERVER_NAME");
+    gethostname(servername, sizeof(servername));
+
+   /*
+    * Then flag whether we are using SSL on this connection...
+    */
+
+    ishttps = getenv("HTTPS") != NULL;
+  }
+
+ /*
+  * Convert the URI to a URL...
+  */
+
+  httpSeparate(uri, method, userpass, hostname, &port, rawresource);
+
+  if (strcmp(method, "ipp") == 0 ||
+      strcmp(method, "http") == 0)
+  {
+   /*
+    * Rewrite the resource string so it doesn't contain any
+    * illegal chars...
+    */
+
+    for (rawptr = rawresource, resptr = resource; *rawptr;)
+      if ((*rawptr & 128) || *rawptr == '%' || *rawptr == ' ' ||
+	  *rawptr == '#' || *rawptr == '?' ||
+	  *rawptr == '.') /* For MSIE */
+      {
+	if (resptr < (resource + sizeof(resource) - 3))
+	{
+	  *resptr++ = '%';
+	  *resptr++ = hexchars[(*rawptr >> 4) & 15];
+	  *resptr++ = hexchars[*rawptr & 15];
+	}
+      }
+      else if (resptr < (resource + sizeof(resource) - 1))
+	*resptr++ = *rawptr++;
+
+    *resptr = '\0';
+
+   /*
+    * Map local access to a local URI...
+    */
+
+    if (strcasecmp(hostname, server) == 0 ||
+	strcasecmp(hostname, servername) == 0)
+    {
+     /*
+      * Make URI relative to the current server...
+      */
+
+      strlcpy(url, resource, urlsize);
+    }
+    else
+    {
+     /*
+      * Rewrite URI with HTTP/HTTPS scheme...
+      */
+
+      if (userpass[0])
+	snprintf(url, urlsize, "%s://%s@%s:%d%s",
+		 ishttps ? "https" : "http",
+		 userpass, hostname, port, resource);
+      else
+	snprintf(url, urlsize, "%s://%s:%d%s", 
+		 ishttps ? "https" : "http",
+		 hostname, port, resource);
+    }
+  }
+  else
+    strlcpy(url, uri, urlsize);
+
+  return (url);
+}
+
+
 /*
  * 'ippSetServerVersion()' - Set the server name and CUPS version...
  */
@@ -98,15 +339,6 @@ ippSetCGIVars(ipp_t      *response,	/* I - Response data to be copied... */
 			*nameptr,	/* Pointer into name */
 			value[16384],	/* Value(s) */
 			*valptr;	/* Pointer into value */
-  char			method[HTTP_MAX_URI],
-			username[HTTP_MAX_URI],
-			hostname[HTTP_MAX_URI],
-			resource[HTTP_MAX_URI],
-			uri[HTTP_MAX_URI];
-  int			port;		/* URI data */
-  int			ishttps;	/* Using encryption? */
-  const char		*server;	/* Name of server */
-  char			servername[1024];/* Locale server name */
   struct tm		*date;		/* Date information */
 
 
@@ -120,21 +352,6 @@ ippSetCGIVars(ipp_t      *response,	/* I - Response data to be copied... */
   if (!prefix)
     ippSetServerVersion();
 
- /*
-  * Get the server name associated with the client interface as well as
-  * the locally configured hostname.  We'll check *both* of these to
-  * see if the printer URL is local...
-  */
-
-  server = getenv("SERVER_NAME");
-  gethostname(servername, sizeof(servername));
-
- /*
-  * Flag whether we are using SSL on this connection...
-  */
-
-  ishttps = getenv("HTTPS") != NULL;
-
  /*
   * Loop through the attributes and set them for the template...
   */
@@ -205,7 +422,7 @@ ippSetCGIVars(ipp_t      *response,	/* I - Response data to be copied... */
       * attribute...
       */
 
-      if (strcmp(name, "job_printer_uri") == 0)
+      if (!strcmp(name, "job_printer_uri"))
       {
         if ((valptr = strrchr(attr->values[0].string.text, '/')) == NULL)
 	  valptr = "unknown";
@@ -235,7 +452,11 @@ ippSetCGIVars(ipp_t      *response,	/* I - Response data to be copied... */
 	  case IPP_TAG_ENUM :
 	      if (strncmp(name, "time_at_", 8) == 0)
 	      {
-	        date = localtime((time_t *)&(attr->values[i].integer));
+	        time_t	t;		/* Temporary time value */
+
+                t    = (time_t)attr->values[i].integer;
+	        date = localtime(&t);
+
 		strftime(valptr, sizeof(value) - (valptr - value),
 		         CUPS_STRFTIME_FORMAT, date);
 	      }
@@ -270,44 +491,13 @@ ippSetCGIVars(ipp_t      *response,	/* I - Response data to be copied... */
 	  case IPP_TAG_URI :
 	      if (strchr(attr->values[i].string.text, ':') != NULL)
 	      {
-		httpSeparate(attr->values[i].string.text, method, username,
-		             hostname, &port, resource);
+	       /*
+	        * Rewrite URIs...
+		*/
 
-        	if (strcmp(method, "ipp") == 0 ||
-	            strcmp(method, "http") == 0)
-        	{
-        	 /*
-		  * Map local access to a local URI...
-		  */
-
-        	  if (strcasecmp(hostname, server) == 0 ||
-		      strcasecmp(hostname, servername) == 0)
-		  {
-		   /*
-		    * Make URI relative to the current server...
-		    */
-
-                    strlcpy(uri, resource, sizeof(uri));
-		  }
-		  else
-		  {
-        	   /*
-		    * Rewrite URI with HTTP address...
-		    */
-
-		    if (username[0])
-		      snprintf(uri, sizeof(uri), "%s://%s@%s:%d%s",
-		               ishttps ? "https" : "http",
-		               username, hostname, port, resource);
-        	    else
-		      snprintf(uri, sizeof(uri), "%s://%s:%d%s", 
-		               ishttps ? "https" : "http",
-			       hostname, port, resource);
-                  }
-
-		  strlcat(valptr, uri, sizeof(value) - (valptr - value));
-        	  break;
-        	}
+		ippRewriteURL(attr->values[i].string.text, valptr,
+		              sizeof(value) - (valptr - value));
+        	break;
               }
 
           case IPP_TAG_STRING :
@@ -353,5 +543,5 @@ ippSetCGIVars(ipp_t      *response,	/* I - Response data to be copied... */
 
 
 /*
- * End of "$Id: ipp-var.c,v 1.34 2003/04/08 03:45:14 mike Exp $".
+ * End of "$Id: ipp-var.c,v 1.40 2003/11/07 18:52:38 mike Exp $".
  */
