@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp-var.h,v 1.9 2003/04/08 03:45:14 mike Exp $"
+ * "$Id: ipp-var.h,v 1.11 2003/11/07 18:52:38 mike Exp $"
  *
  *   IPP variable definitions for the Common UNIX Printing System (CUPS).
  *
@@ -44,12 +44,15 @@
  * Prototype...
  */
 
+extern void	ippGetAttributes(ipp_t *request, const char *directory,
+		                 const char *tmpl, const char *lang);
 extern char	*ippGetTemplateDir(void);
+extern char	*ippRewriteURL(const char *, char *, int);
 extern void	ippSetServerVersion(void);
 extern void	ippSetCGIVars(ipp_t *, const char *, const char *,
 		              const char *, int);
 
 
 /*
- * End of "$Id: ipp-var.h,v 1.9 2003/04/08 03:45:14 mike Exp $".
+ * End of "$Id: ipp-var.h,v 1.11 2003/11/07 18:52:38 mike Exp $".
  */
