@@ -1,5 +1,5 @@
 /*
- * "$Id: printers.c,v 1.28 2003/04/08 03:45:14 mike Exp $"
+ * "$Id: printers.c,v 1.30 2003/11/07 18:52:38 mike Exp $"
  *
  *   Printer status CGI for the Common UNIX Printing System (CUPS).
  *
@@ -37,24 +37,26 @@
  * 'main()' - Main entry for CGI.
  */
 
-int				/* O - Exit status */
-main(int  argc,			/* I - Number of command-line arguments */
-     char *argv[])		/* I - Command-line arguments */
+int					/* O - Exit status */
+main(int  argc,				/* I - Number of command-line arguments */
+     char *argv[])			/* I - Command-line arguments */
 {
-  cups_lang_t	*language;	/* Language information */
-  char		*printer;	/* Printer name */
-  http_t	*http;		/* Connection to the server */
-  ipp_t		*request,	/* IPP request */
-		*response;	/* IPP response */
-  ipp_attribute_t *attr;	/* IPP attribute */
-  ipp_status_t	status;		/* Operation status... */
-  char		uri[HTTP_MAX_URI];
-				/* Printer URI */
-  const char	*which_jobs;	/* Which jobs to show */
-  const char	*op;		/* Operation to perform, if any */
- 
+  cups_lang_t	*language;		/* Language information */
+  char		*printer;		/* Printer name */
+  http_t	*http;			/* Connection to the server */
+  ipp_t		*request,		/* IPP request */
+		*response;		/* IPP response */
+  ipp_attribute_t *attr;		/* IPP attribute */
+  ipp_status_t	status;			/* Operation status... */
+  char		uri[HTTP_MAX_URI];	/* Printer URI */
+  const char	*which_jobs;		/* Which jobs to show */
+  const char	*op;			/* Operation to perform, if any */
+  static const char	*def_attrs[] =	/* Attributes for default printer */
+		{
+		  "printer-name",
+		  "printer-uri-supported"
+		};
 
-  setbuf(stdout, NULL);
 
  /*
   * Get any form variables...
@@ -116,6 +118,10 @@ main(int  argc,			/* I - Number of command-line arguments */
     ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
         	 "attributes-natural-language", NULL, language->language);
 
+    ippAddStrings(request, IPP_TAG_OPERATION, IPP_TAG_KEYWORD,
+                  "requested-attributes",
+		  sizeof(def_attrs) / sizeof(def_attrs[0]), NULL, def_attrs);
+
     if ((response = cupsDoRequest(http, request, "/")) != NULL)
     {
       if ((attr = ippFindAttribute(response, "printer-name", IPP_TAG_NAME)) != NULL)
@@ -123,38 +129,12 @@ main(int  argc,			/* I - Number of command-line arguments */
 
       if ((attr = ippFindAttribute(response, "printer-uri-supported", IPP_TAG_URI)) != NULL)
       {
-	char	method[HTTP_MAX_URI],
-		username[HTTP_MAX_URI],
-		hostname[HTTP_MAX_URI],
-		resource[HTTP_MAX_URI],
-		uri[HTTP_MAX_URI];
-	int	port;			/* URI data */
-	const char *server;		/* Name of server */
+	char	url[HTTP_MAX_URI];	/* New URL */
 
 
-       /*
-	* Map localhost access to localhost...
-	*/
-
-        server = getenv("SERVER_NAME");
-
-	httpSeparate(attr->values[0].string.text, method, username,
-		     hostname, &port, resource);
-
-	if (strcasecmp(hostname, server) == 0 &&
-	    (strcmp(getenv("REMOTE_HOST"), "127.0.0.1") == 0 ||
-	     strcmp(getenv("REMOTE_HOST"), "localhost") == 0 ||
-	     strcmp(getenv("REMOTE_HOST"), server) == 0))
-	  strcpy(hostname, "localhost");
-
-       /*
-	* Rewrite URI with HTTP address...
-	*/
-
-	snprintf(uri, sizeof(uri), "http://%s:%d%s", hostname, port,
-		 resource);
-
-        cgiSetVariable("DEFAULT_URI", uri);
+        cgiSetVariable("DEFAULT_URI",
+	               ippRewriteURL(attr->values[0].string.text,
+		                     url, sizeof(url)));
       }
 
       ippDelete(response);
@@ -205,8 +185,7 @@ main(int  argc,			/* I - Number of command-line arguments */
                    uri);
     }
 
-    ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_KEYWORD,
-        	 "requested-attributes", NULL, "all");
+    ippGetAttributes(request, TEMPLATES, "printers.tmpl", getenv("LANG"));
 
    /*
     * Do the request and get back a response...
@@ -265,6 +244,8 @@ main(int  argc,			/* I - Number of command-line arguments */
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_KEYWORD, "which-jobs",
                      NULL, which_jobs);
 
+      ippGetAttributes(request, TEMPLATES, "jobs.tmpl", getenv("LANG"));
+
      /*
       * Do the request and get back a response...
       */
@@ -371,5 +352,5 @@ main(int  argc,			/* I - Number of command-line arguments */
 
 
 /*
- * End of "$Id: printers.c,v 1.28 2003/04/08 03:45:14 mike Exp $".
+ * End of "$Id: printers.c,v 1.30 2003/11/07 18:52:38 mike Exp $".
  */
