@@ -1,5 +1,5 @@
 /*
- * "$Id: cups.h,v 1.48 2003/04/03 03:30:12 mike Exp $"
+ * "$Id: cups.h,v 1.52 2003/08/29 21:26:40 mike Exp $"
  *
  *   API definitions for the Common UNIX Printing System (CUPS).
  *
@@ -48,10 +48,10 @@ extern "C" {
  * Constants...
  */
 
-#  define CUPS_VERSION		1.0119
+#  define CUPS_VERSION		1.0120
 #  define CUPS_VERSION_MAJOR	1
 #  define CUPS_VERSION_MINOR	1
-#  define CUPS_VERSION_PATCH	19
+#  define CUPS_VERSION_PATCH	20
 #  define CUPS_DATE_ANY		-1
 
 
@@ -82,7 +82,7 @@ enum					/* Not a typedef'd enum so we can OR */
   CUPS_PRINTER_IMPLICIT = 0x10000,	/* Implicit class */
   CUPS_PRINTER_DEFAULT = 0x20000,	/* Default printer on network */
   CUPS_PRINTER_FAX = 0x40000,		/* Fax queue */
-  CUPS_PRINTER_OPTIONS = 0xfffc		/* ~(CLASS | REMOTE | IMPLICIT) */
+  CUPS_PRINTER_OPTIONS = 0x6fffc	/* ~(CLASS | REMOTE | IMPLICIT) */
 };
 
 typedef struct				/**** Printer Options ****/
@@ -170,6 +170,17 @@ extern void		cupsSetServer(const char *server);
 extern void		cupsSetUser(const char *user);
 extern const char	*cupsUser(void);
 
+/**** New in CUPS 1.1.20 ****/
+extern int		cupsDoAuthentication(http_t *http, const char *method,
+			                     const char *resource);
+extern http_status_t	cupsGetFile(http_t *http, const char *resource,
+			            const char *filename);
+extern http_status_t	cupsGetFd(http_t *http, const char *resource, int fd);
+extern http_status_t	cupsPutFile(http_t *http, const char *resource,
+			            const char *filename);
+extern http_status_t	cupsPutFd(http_t *http, const char *resource, int fd);
+
+
 #  ifdef __cplusplus
 }
 #  endif /* __cplusplus */
@@ -177,5 +188,5 @@ extern const char	*cupsUser(void);
 #endif /* !_CUPS_CUPS_H_ */
 
 /*
- * End of "$Id: cups.h,v 1.48 2003/04/03 03:30:12 mike Exp $".
+ * End of "$Id: cups.h,v 1.52 2003/08/29 21:26:40 mike Exp $".
  */
