@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp.c,v 1.91 2003/05/09 16:05:28 mike Exp $"
+ * "$Id: ipp.c,v 1.94 2003/11/07 18:59:18 mike Exp $"
  *
  *   Internet Printing Protocol support functions for the Common UNIX
  *   Printing System (CUPS).
@@ -77,6 +77,10 @@
 #include <ctype.h>
 #include <errno.h>
 
+#ifdef WIN32
+#  include <io.h>
+#endif // WIN32
+
 
 /*
  * Local functions...
@@ -1718,7 +1722,7 @@ ippWriteIO(void       *dst,			/* I - Destination */
                   DEBUG_printf(("ippWrite: writing string = %d, \'%s\'\n", n,
 		                value->string.text));
 
-                  if ((sizeof(buffer) - (bufptr - buffer)) < (n + 2))
+                  if ((int)(sizeof(buffer) - (bufptr - buffer)) < (n + 2))
 		  {
                     if ((*cb)(dst, buffer, bufptr - buffer) < 0)
 	            {
@@ -1943,7 +1947,7 @@ ippWriteIO(void       *dst,			/* I - Destination */
                   if (n > (sizeof(buffer) - 2))
 		    return (IPP_ERROR);
 
-                  if ((sizeof(buffer) - (bufptr - buffer)) < (n + 2))
+                  if ((int)(sizeof(buffer) - (bufptr - buffer)) < (n + 2))
 		  {
                     if ((*cb)(dst, buffer, bufptr - buffer) < 0)
 	            {
@@ -2093,7 +2097,7 @@ ippWriteIO(void       *dst,			/* I - Destination */
                   if (n > (sizeof(buffer) - 2))
 		    return (IPP_ERROR);
 
-                  if ((sizeof(buffer) - (bufptr - buffer)) < (n + 2))
+                  if ((int)(sizeof(buffer) - (bufptr - buffer)) < (n + 2))
 		  {
                     if ((*cb)(dst, buffer, bufptr - buffer) < 0)
 	            {
@@ -2491,16 +2495,24 @@ ipp_read_http(http_t      *http,		/* I - Client connection */
       * Wait a maximum of 1 second for data...
       */
 
-      if (!httpWait(http, 1000))
+      if (!http->blocking)
       {
        /*
-        * Signal no data...
+        * Wait up to 1 second for more data on non-blocking sockets...
 	*/
 
-        bytes = -1;
-	break;
+	if (!httpWait(http, 1000))
+	{
+	 /*
+          * Signal no data...
+	  */
+
+          bytes = -1;
+	  break;
+	}
       }
-      else if ((bytes = httpRead(http, (char *)buffer, length - tbytes)) < 0)
+
+      if ((bytes = httpRead(http, (char *)buffer, length - tbytes)) <= 0)
         break;
     }
   }
@@ -2545,5 +2557,5 @@ ipp_write_file(int         *fd,			/* I - File descriptor */
 
 
 /*
- * End of "$Id: ipp.c,v 1.91 2003/05/09 16:05:28 mike Exp $".
+ * End of "$Id: ipp.c,v 1.94 2003/11/07 18:59:18 mike Exp $".
  */
