@@ -1,5 +1,5 @@
 /*
- * "$Id: imagetops.c,v 1.50 2002/12/17 18:59:28 swdev Exp $"
+ * "$Id: imagetops.c,v 1.53 2003/04/15 12:57:15 mike Exp $"
  *
  *   Image file to PostScript filter for the Common UNIX Printing System (CUPS).
  *
@@ -171,7 +171,7 @@ main(int  argc,		/* I - Number of command-line arguments */
   options     = NULL;
   num_options = cupsParseOptions(argv[5], 0, &options);
 
-  ppd = SetCommonOptions(num_options, options, 1);
+  ppd = SetCommonOptions(num_options, options, 0);
 
   if ((val = cupsGetOption("multiple-document-handling", num_options, options)) != NULL)
   {
@@ -410,16 +410,6 @@ main(int  argc,		/* I - Number of command-line arguments */
 	yinches     = ysize2;
 	xprint      = (PageTop - PageBottom) / 72.0;
 	yprint      = (PageRight - PageLeft) / 72.0;
-
-	xsize       = PageLeft;
-	PageLeft    = PageBottom;
-	PageBottom  = PageWidth - PageRight;
-	PageRight   = PageTop;
-	PageTop     = PageLength - xsize;
-
-	xsize       = PageWidth;
-	PageWidth   = PageLength;
-	PageLength  = xsize;
       }
       else
       {
@@ -442,16 +432,6 @@ main(int  argc,		/* I - Number of command-line arguments */
       yinches     = ysize2;
       xprint      = (PageTop - PageBottom) / 72.0;
       yprint      = (PageRight - PageLeft) / 72.0;
-
-      xsize       = PageLeft;
-      PageLeft    = PageBottom;
-      PageBottom  = PageWidth - PageRight;
-      PageRight   = PageTop;
-      PageTop     = PageLength - xsize;
-
-      xsize       = PageWidth;
-      PageWidth   = PageLength;
-      PageLength  = xsize;
     }
     else
     {
@@ -605,6 +585,7 @@ main(int  argc,		/* I - Number of command-line arguments */
     printf("{ neg 1 add dup 0 lt { pop 1 } { %.3f exp neg 1 add } "
            "ifelse %.3f mul } bind settransfer\n", g, b);
 
+  WriteCommon();
   WriteLabelProlog(cupsGetOption("page-label", num_options, options),
                    PageBottom, PageTop, PageWidth);
 
@@ -624,6 +605,16 @@ main(int  argc,		/* I - Number of command-line arguments */
 
   row = malloc(img->xsize * abs(colorspace) + 3);
 
+  UpdatePageVars();
+
+  fprintf(stderr, "DEBUG: XPosition=%d, YPosition=%d, Orientation=%d\n",
+          XPosition, YPosition, Orientation);
+  fprintf(stderr, "DEBUG: xprint=%.0f, yprint=%.0f\n", xprint, yprint);
+  fprintf(stderr, "DEBUG: PageLeft=%.0f, PageRight=%.0f, PageWidth=%.0f\n",
+          PageLeft, PageRight, PageWidth);
+  fprintf(stderr, "DEBUG: PageBottom=%.0f, PageTop=%.0f, PageLength=%.0f\n",
+          PageBottom, PageTop, PageLength);
+
   for (page = 1; Copies > 0; Copies --)
     for (xpage = 0; xpage < xpages; xpage ++)
       for (ypage = 0; ypage < ypages; ypage ++, page ++)
@@ -663,10 +654,10 @@ main(int  argc,		/* I - Number of command-line arguments */
         switch (XPosition)
 	{
 	  case -1 :
-	      left = PageLeft;
+              left = PageLeft;
 	      break;
 	  default :
-	      left = (PageWidth - xprint * 72.0) * 0.5;
+	      left = (PageLeft + PageRight - xprint * 72.0) * 0.5;
 	      break;
 	  case 1 :
 	      left = PageRight - xprint * 72.0;
@@ -679,7 +670,7 @@ main(int  argc,		/* I - Number of command-line arguments */
 	      top = PageBottom + 72.0 * yprint;
 	      break;
 	  default :
-	      top = (PageLength + yprint * 72.0) * 0.5;
+	      top = (PageBottom + PageTop + yprint * 72.0) * 0.5;
 	      break;
 	  case 1 :
 	      top = PageTop;
@@ -911,5 +902,5 @@ ps_ascii85(ib_t *data,		/* I - Data to print */
 
 
 /*
- * End of "$Id: imagetops.c,v 1.50 2002/12/17 18:59:28 swdev Exp $".
+ * End of "$Id: imagetops.c,v 1.53 2003/04/15 12:57:15 mike Exp $".
  */
