@@ -2,7 +2,7 @@
 //
 // GlobalParams.cc
 //
-// Copyright 2001-2002 Glyph & Cog, LLC
+// Copyright 2001-2003 Glyph & Cog, LLC
 //
 //========================================================================
 
@@ -357,6 +357,12 @@ void GlobalParams::parseFile(GString *fileName, FILE *f) {
       } else if (!cmd->cmp("displayCIDFontT1")) {
 	parseDisplayFont(tokens, displayCIDFonts,
 			 displayFontT1, fileName, line);
+      } else if (!cmd->cmp("displayNamedCIDFontTT")) {
+	parseDisplayFont(tokens, displayNamedCIDFonts,
+			 displayFontTT, fileName, line);
+      } else if (!cmd->cmp("displayCIDFontTT")) {
+	parseDisplayFont(tokens, displayCIDFonts,
+			 displayFontTT, fileName, line);
       } else if (!cmd->cmp("psFile")) {
 	parsePSFile(tokens, fileName, line);
       } else if (!cmd->cmp("psFont")) {
@@ -961,6 +967,15 @@ GBool GlobalParams::getPSDuplex() {
   return d;
 }
 
+GBool GlobalParams::getPSFit() {
+  GBool d;
+
+  globalParamsLock;
+  d = psFit;
+  globalParamsUnlock;
+  return d;
+}
+
 PSLevel GlobalParams::getPSLevel() {
   PSLevel level;
 
@@ -1076,25 +1091,17 @@ GBool GlobalParams::getTextKeepTinyChars() {
 }
 
 GString *GlobalParams::findFontFile(GString *fontName,
-				    const char *ext1, const char *ext2) {
+				    const char **exts) {
   GString *dir, *fileName;
+  const char **ext;
   FILE *f;
   int i;
 
   for (i = 0; i < fontDirs->getLength(); ++i) {
     dir = (GString *)fontDirs->get(i);
-    if (ext1) {
+    for (ext = exts; *ext; ++ext) {
       fileName = appendToPath(dir->copy(), fontName->getCString());
-      fileName->append(ext1);
-      if ((f = fopen(fileName->getCString(), "r"))) {
-	fclose(f);
-	return fileName;
-      }
-      delete fileName;
-    }
-    if (ext2) {
-      fileName = appendToPath(dir->copy(), fontName->getCString());
-      fileName->append(ext2);
+      fileName->append(*ext);
       if ((f = fopen(fileName->getCString(), "r"))) {
 	fclose(f);
 	return fileName;
@@ -1241,7 +1248,9 @@ void GlobalParams::setPSImageableArea(int left, int bottom, int right, int top)
 
 GBool GlobalParams::setPSPaperSize(const char *size) {
   globalParamsLock;
-  if (!strcmp(size, "letter")) {
+  if (!strcmp(size, "match")) {
+    psPaperWidth = psPaperHeight = -1;
+  } else if (!strcmp(size, "letter")) {
     psPaperWidth = 612;
     psPaperHeight = 792;
   } else if (!strcmp(size, "legal")) {
@@ -1290,6 +1299,12 @@ void GlobalParams::setPSDuplex(GBool duplex) {
   globalParamsUnlock;
 }
 
+void GlobalParams::setPSFit(GBool fit) {
+  globalParamsLock;
+  psFit = fit;
+  globalParamsUnlock;
+}
+
 void GlobalParams::setPSLevel(PSLevel level) {
   globalParamsLock;
   psLevel = level;
