@@ -2,7 +2,7 @@
 //
 // GlobalParams.h
 //
-// Copyright 2001-2002 Glyph & Cog, LLC
+// Copyright 2001-2003 Glyph & Cog, LLC
 //
 //========================================================================
 
@@ -146,6 +146,7 @@ public:
   int getPSPaperWidth();
   int getPSPaperHeight();
   GBool getPSDuplex();
+  GBool getPSFit();
   PSLevel getPSLevel();
   PSFontParam *getPSFont(GString *fontName);
   PSFontParam *getPSFont16(GString *fontName, GString *collection, int wMode);
@@ -157,7 +158,7 @@ public:
   GBool getPSASCIIHex();
   EndOfLineKind getTextEOL();
   GBool getTextKeepTinyChars();
-  GString *findFontFile(GString *fontName, const char *ext1, const char *ext2);
+  GString *findFontFile(GString *fontName, const char **exts);
   GString *getInitialZoom();
   FontRastControl getT1libControl();
   FontRastControl getFreeTypeControl();
@@ -181,6 +182,7 @@ public:
   void setPSPaperWidth(int width);
   void setPSPaperHeight(int height);
   void setPSDuplex(GBool duplex);
+  void setPSFit(GBool fit);
   void setPSLevel(PSLevel level);
   void setPSEmbedType1(GBool embed);
   void setPSEmbedTrueType(GBool embed);
@@ -261,6 +263,7 @@ private:
   int psRight;			//   ...
   int psTop;			//   ...
   GBool psDuplex;		// enable duplexing in PostScript?
+  GBool psFit;			// fit pages to device?
   PSLevel psLevel;		// PostScript level to generate
   GHash *psFonts;		// PostScript font info, indexed by PDF
 				//   font name [PSFontParam]
