@@ -1,5 +1,5 @@
 /*
- * "$Id: cert.c,v 1.15 2002/12/17 19:00:13 swdev Exp $"
+ * "$Id: cert.c,v 1.17 2003/03/30 19:50:33 mike Exp $"
  *
  *   Authentication certificate routines for the Common UNIX
  *   Printing System (CUPS).
@@ -53,7 +53,7 @@ AddCert(int        pid,			/* I - Process ID */
   int		fd;			/* Certificate file */
   char		filename[1024];		/* Certificate filename */
   struct group	*grp;			/* System group */
-  static const char *hex = "0123456789ABCDEF";
+  static const char hex[] = "0123456789ABCDEF";
 					/* Hex constants... */
 
 
@@ -247,7 +247,7 @@ FindCert(const char *certificate)	/* I - Certificate */
 void
 InitCerts(void)
 {
-  FILE		*fp;			/* /dev/random file */
+  cups_file_t	*fp;			/* /dev/random file */
   unsigned	seed;			/* Seed for random number generator */
   struct timeval tod;			/* Time of day */
 
@@ -257,7 +257,7 @@ InitCerts(void)
   * the current time, as available...
   */
 
-  if ((fp = fopen("/dev/urandom", "rb")) == NULL)
+  if ((fp = cupsFileOpen("/dev/urandom", "rb")) == NULL)
   {
    /*
     * Get the time in usecs and use it as the initial seed...
@@ -274,12 +274,12 @@ InitCerts(void)
     * them as the seed...
     */
 
-    seed = getc(fp);
-    seed = (seed << 8) | getc(fp);
-    seed = (seed << 8) | getc(fp);
-    seed = (seed << 8) | getc(fp);
+    seed = cupsFileGetChar(fp);
+    seed = (seed << 8) | cupsFileGetChar(fp);
+    seed = (seed << 8) | cupsFileGetChar(fp);
+    seed = (seed << 8) | cupsFileGetChar(fp);
 
-    fclose(fp);
+    cupsFileClose(fp);
   }
 
   srandom(seed);
@@ -293,5 +293,5 @@ InitCerts(void)
 
 
 /*
- * End of "$Id: cert.c,v 1.15 2002/12/17 19:00:13 swdev Exp $".
+ * End of "$Id: cert.c,v 1.17 2003/03/30 19:50:33 mike Exp $".
  */
