@@ -1,5 +1,5 @@
 /*
- * "$Id: classes.c,v 1.52 2003/04/26 17:09:55 mike Exp $"
+ * "$Id: classes.c,v 1.53 2003/09/15 19:40:44 mike Exp $"
  *
  *   Printer class routines for the Common UNIX Printing System (CUPS).
  *
@@ -610,7 +610,7 @@ SaveAllClasses(void)
   * Restrict access to the file...
   */
 
-  fchown(cupsFileNumber(fp), User, Group);
+  fchown(cupsFileNumber(fp), getuid(), Group);
   fchmod(cupsFileNumber(fp), ConfigFilePerm);
 
  /*
@@ -689,5 +689,5 @@ SaveAllClasses(void)
 
 
 /*
- * End of "$Id: classes.c,v 1.52 2003/04/26 17:09:55 mike Exp $".
+ * End of "$Id: classes.c,v 1.53 2003/09/15 19:40:44 mike Exp $".
  */
