@@ -1,5 +1,5 @@
 /*
- * "$Id: client.c,v 1.160 2003/05/09 16:10:22 mike Exp $"
+ * "$Id: client.c,v 1.175 2003/09/29 14:51:20 mike Exp $"
  *
  *   Client routines for the Common UNIX Printing System (CUPS) scheduler.
  *
@@ -344,7 +344,6 @@ CloseAllClients(void)
 void
 CloseClient(client_t *con)	/* I - Client to close */
 {
-  int		status;		/* Exit status of pipe command */
 #if defined(HAVE_LIBSSL)
   SSL_CTX	*context;	/* Context for encryption */
   SSL		*conn;		/* Connection for encryption */
@@ -452,10 +451,7 @@ CloseClient(client_t *con)	/* I - Client to close */
     */
 
     if (con->pipe_pid)
-    {
       kill(con->pipe_pid, SIGKILL);
-      waitpid(con->pipe_pid, &status, WNOHANG);
-    }
 
     LogMessage(L_DEBUG2, "CloseClient: %d Closing data file %d.",
                con->http.fd, con->file);
@@ -500,7 +496,7 @@ CloseClient(client_t *con)	/* I - Client to close */
   NumClients --;
 
   if (con < (Clients + NumClients))
-    memcpy(con, con + 1, (Clients + NumClients - con) * sizeof(client_t));
+    memmove(con, con + 1, (Clients + NumClients - con) * sizeof(client_t));
 }
 
 
@@ -818,23 +814,25 @@ IsCGI(client_t    *con,				/* I - Client connection */
  * 'ReadClient()' - Read data from a client.
  */
 
-int				/* O - 1 on success, 0 on error */
-ReadClient(client_t *con)	/* I - Client to read from */
+int					/* O - 1 on success, 0 on error */
+ReadClient(client_t *con)		/* I - Client to read from */
 {
-  char		line[32768],	/* Line from client... */
-		operation[64],	/* Operation code from socket */
-		version[64];	/* HTTP version number string */
-  int		major, minor;	/* HTTP version numbers */
-  http_status_t	status;		/* Transfer status */
-  ipp_state_t   ipp_state;	/* State of IPP transfer */
-  int		bytes;		/* Number of bytes to POST */
-  char		*filename;	/* Name of file for GET/HEAD */
-  char		buf[1024];	/* Buffer for real filename */
-  struct stat	filestats;	/* File information */
-  mime_type_t	*type;		/* MIME type of file */
-  printer_t	*p;		/* Printer */
-  location_t	*best;		/* Best match for authentication */
-  static unsigned request_id = 0;/* Request ID for temp files */
+  char		line[32768],		/* Line from client... */
+		operation[64],		/* Operation code from socket */
+		version[64],		/* HTTP version number string */
+		locale[64],		/* Locale */
+		*ptr;			/* Pointer into strings */
+  int		major, minor;		/* HTTP version numbers */
+  http_status_t	status;			/* Transfer status */
+  ipp_state_t   ipp_state;		/* State of IPP transfer */
+  int		bytes;			/* Number of bytes to POST */
+  char		*filename;		/* Name of file for GET/HEAD */
+  char		buf[1024];		/* Buffer for real filename */
+  struct stat	filestats;		/* File information */
+  mime_type_t	*type;			/* MIME type of file */
+  printer_t	*p;			/* Printer */
+  location_t	*best;			/* Best match for authentication */
+  static unsigned request_id = 0;	/* Request ID for temp files */
 
 
   status = HTTP_CONTINUE;
@@ -1048,7 +1046,40 @@ ReadClient(client_t *con)	/* I - Client to read from */
 
   if (status == HTTP_OK)
   {
-    con->language = cupsLangGet(con->http.fields[HTTP_FIELD_ACCEPT_LANGUAGE]);
+    if (con->http.fields[HTTP_FIELD_ACCEPT_LANGUAGE][0])
+    {
+     /*
+      * Figure out the locale from the Accept-Language and Content-Type
+      * fields...
+      */
+
+      if ((ptr = strchr(con->http.fields[HTTP_FIELD_ACCEPT_LANGUAGE], ',')) != NULL)
+        *ptr = '\0';
+
+      if ((ptr = strchr(con->http.fields[HTTP_FIELD_ACCEPT_LANGUAGE], ';')) != NULL)
+        *ptr = '\0';
+
+      if ((ptr = strstr(con->http.fields[HTTP_FIELD_CONTENT_TYPE], "charset=")) != NULL)
+      {
+       /*
+        * Combine language and charset, and trim any extra params in the
+	* content-type.
+	*/
+
+        snprintf(locale, sizeof(locale), "%s.%s",
+	         con->http.fields[HTTP_FIELD_ACCEPT_LANGUAGE], ptr + 8);
+
+	if ((ptr = strchr(locale, ',')) != NULL)
+	  *ptr = '\0';
+      }
+      else
+        snprintf(locale, sizeof(locale), "%s.%s",
+	         con->http.fields[HTTP_FIELD_ACCEPT_LANGUAGE], DefaultCharset);
+        
+      con->language = cupsLangGet(locale);
+    }
+    else
+      con->language = cupsLangGet(DefaultLocale);
 
     decode_auth(con);
 
@@ -1235,7 +1266,7 @@ ReadClient(client_t *con)	/* I - Client to read from */
 	      }
 
 	      if (con->options[0] == '/')
-		strcpy(con->options, con->options + 1);
+		cups_strcpy(con->options, con->options + 1);
 
               if (!SendCommand(con, con->command, con->options))
 	      {
@@ -1409,7 +1440,7 @@ ReadClient(client_t *con)	/* I - Client to read from */
 	      }
 
 	      if (con->options[0] == '/')
-		strcpy(con->options, con->options + 1);
+		cups_strcpy(con->options, con->options + 1);
 
               LogMessage(L_DEBUG2, "ReadClient() %d command=\"%s\", options = \"%s\"",
 	        	 con->http.fd, con->command, con->options);
@@ -1499,6 +1530,20 @@ ReadClient(client_t *con)	/* I - Client to read from */
 
 	      break;
             }
+	    else if (atoi(con->http.fields[HTTP_FIELD_CONTENT_LENGTH]) < 0)
+	    {
+	     /*
+	      * Negative content lengths are invalid!
+	      */
+
+              if (!SendError(con, HTTP_BAD_REQUEST))
+	      {
+		CloseClient(con);
+		return (0);
+	      }
+
+	      break;
+	    }
 
            /*
 	    * Open a temporary file to hold the request...
@@ -1507,7 +1552,7 @@ ReadClient(client_t *con)	/* I - Client to read from */
             SetStringf(&con->filename, "%s/%08x", RequestRoot, request_id ++);
 	    con->file = open(con->filename, O_WRONLY | O_CREAT | O_TRUNC, 0640);
 	    fchmod(con->file, 0640);
-	    fchown(con->file, User, Group);
+	    fchown(con->file, getuid(), Group);
 
             LogMessage(L_DEBUG2, "ReadClient() %d REQUEST %s=%d", con->http.fd,
 	               con->filename, con->file);
@@ -1799,7 +1844,7 @@ ReadClient(client_t *con)	/* I - Client to read from */
           SetStringf(&con->filename, "%s/%08x", RequestRoot, request_id ++);
 	  con->file = open(con->filename, O_WRONLY | O_CREAT | O_TRUNC, 0640);
 	  fchmod(con->file, 0640);
-	  fchown(con->file, User, Group);
+	  fchown(con->file, getuid(), Group);
 
           LogMessage(L_DEBUG2, "ReadClient() %d REQUEST %s=%d", con->http.fd,
 	             con->filename, con->file);
@@ -2004,7 +2049,8 @@ SendError(client_t      *con,	/* I - Connection */
   if (con->operation > HTTP_WAITING)
     LogRequest(con, code);
 
-  LogMessage(L_DEBUG, "SendError() %d code=%d", con->http.fd, code);
+  LogMessage(L_DEBUG, "SendError() %d code=%d (%s)", con->http.fd, code,
+             httpStatus(code));
 
  /*
   * To work around bugs in some proxies, don't use Keep-Alive for some
@@ -2646,14 +2692,15 @@ decode_auth(client_t *con)		/* I - Client to decode to */
  * 'get_file()' - Get a filename and state info.
  */
 
-static char *			/* O  - Real filename */
-get_file(client_t    *con,	/* I  - Client connection */
-         struct stat *filestats,/* O  - File information */
-         char        *filename,	/* IO - Filename buffer */
-         int         len)	/* I  - Buffer length */
+static char *				/* O  - Real filename */
+get_file(client_t    *con,		/* I  - Client connection */
+         struct stat *filestats,	/* O  - File information */
+         char        *filename,		/* IO - Filename buffer */
+         int         len)		/* I  - Buffer length */
 {
-  int		status;		/* Status of filesystem calls */
-  char		*params;	/* Pointer to parameters in URI */
+  int		status;			/* Status of filesystem calls */
+  char		*ptr;			/* Pointer info filename */
+  int		plen;			/* Remaining length after pointer */
 
 
  /*
@@ -2670,8 +2717,8 @@ get_file(client_t    *con,	/* I  - Client connection */
   else
     snprintf(filename, len, "%s%s", DocumentRoot, con->uri);
 
-  if ((params = strchr(filename, '?')) != NULL)
-    *params = '\0';
+  if ((ptr = strchr(filename, '?')) != NULL)
+    *ptr = '\0';
 
  /*
   * Grab the status for this language; if there isn't a language-specific file
@@ -2689,6 +2736,9 @@ get_file(client_t    *con,	/* I  - Client connection */
     {
       snprintf(filename, len, "%s%s", DocumentRoot, con->uri);
 
+      if ((ptr = strchr(filename, '?')) != NULL)
+	*ptr = '\0';
+
       status = stat(filename, filestats);
     }
   }
@@ -2699,12 +2749,52 @@ get_file(client_t    *con,	/* I  - Client connection */
 
   if (!status && S_ISDIR(filestats->st_mode))
   {
-    if (filename[strlen(filename) - 1] == '/')
-      strlcat(filename, "index.html", len);
-    else
-      strlcat(filename, "/index.html", len);
+    if (filename[strlen(filename) - 1] != '/')
+      strlcat(filename, "/", len);
 
+    ptr  = filename + strlen(filename);
+    plen = len - (ptr - filename);
+
+    strlcpy(ptr, "index.html", plen);
     status = stat(filename, filestats);
+
+#ifdef HAVE_JAVA
+    if (status)
+    {
+      strlcpy(ptr, "index.class", plen);
+      status = stat(filename, filestats);
+    }
+#endif /* HAVE_JAVA */
+
+#ifdef HAVE_PERL
+    if (status)
+    {
+      strlcpy(ptr, "index.pl", plen);
+      status = stat(filename, filestats);
+    }
+#endif /* HAVE_PERL */
+
+#ifdef HAVE_PHP
+    if (status)
+    {
+      strlcpy(ptr, "index.php", plen);
+      status = stat(filename, filestats);
+    }
+#endif /* HAVE_PHP */
+
+#ifdef HAVE_PYTHON
+    if (status)
+    {
+      strlcpy(ptr, "index.pyc", plen);
+      status = stat(filename, filestats);
+    }
+
+    if (status)
+    {
+      strlcpy(ptr, "index.py", plen);
+      status = stat(filename, filestats);
+    }
+#endif /* HAVE_PYTHON */
   }
 
   LogMessage(L_DEBUG2, "get_file() %d filename=%s size=%d",
@@ -2865,6 +2955,8 @@ install_conf_file(client_t *con)	/* I - Connection */
   else
     NeedReload = RELOAD_ALL;
 
+  ReloadTime = time(NULL);
+
  /*
   * Return that the file was created successfully...
   */
@@ -2915,11 +3007,43 @@ pipe_command(client_t *con,		/* I - Client connection */
 		script_name[1024],	/* SCRIPT_NAME environment variable */
 		server_name[1024],	/* SERVER_NAME environment variable */
 		server_port[1024],	/* SERVER_PORT environment variable */
-		tmpdir[1024];		/* TMPDIR environment variable */
+		tmpdir[1024],		/* TMPDIR environment variable */
+		vg_args[1024],		/* VG_ARGS environment variable */
+		ld_assume_kernel[1024];	/* LD_ASSUME_KERNEL environment variable */
   unsigned	address;		/* Address of client */
 #if defined(HAVE_SIGACTION) && !defined(HAVE_SIGSET)
   struct sigaction action;		/* POSIX signal handler */
 #endif /* HAVE_SIGACTION && !HAVE_SIGSET */
+  static const char * const locale_encodings[] =
+		{			/* Locale charset names */
+		  "ASCII",
+		  "ISO8859-1",
+		  "ISO8859-2",
+		  "ISO8859-3",
+		  "ISO8859-4",
+		  "ISO8859-5",
+		  "ISO8859-6",
+		  "ISO8859-7",
+		  "ISO8859-8",
+		  "ISO8859-9",
+		  "ISO8859-10",
+		  "UTF-8",
+		  "ISO8859-13",
+		  "ISO8859-14",
+		  "ISO8859-15",
+		  "CP874",
+		  "CP1250",
+		  "CP1251",
+		  "CP1252",
+		  "CP1253",
+		  "CP1254",
+		  "CP1255",
+		  "CP1256",
+		  "CP1257",
+		  "CP1258",
+		  "KOI8R",
+		  "KOI8U"
+		};
 
 
  /*
@@ -2963,7 +3087,7 @@ pipe_command(client_t *con,		/* I - Client connection */
       else
         *commptr |= tolower(commptr[2]) - 'a' + 10;
 
-      strcpy(commptr + 1, commptr + 3);
+      cups_strcpy(commptr + 1, commptr + 3);
     }
     else if (*commptr == '?')
       break;
@@ -2979,11 +3103,15 @@ pipe_command(client_t *con,		/* I - Client connection */
 
   address = ntohl(con->http.hostaddr.sin_addr.s_addr);
 
-  snprintf(lang, sizeof(lang), "LANG=%s",
-           con->language ? con->language->language : "C");
-  sprintf(ipp_port, "IPP_PORT=%d", ntohs(con->http.hostaddr.sin_port));
+  if (con->language)
+    snprintf(lang, sizeof(lang), "LANG=%s.%s", con->language->language,
+             locale_encodings[con->language->encoding]);
+  else
+    strcpy(lang, "LANG=C");
+
+  sprintf(ipp_port, "IPP_PORT=%d", LocalPort);
   sprintf(server_port, "SERVER_PORT=%d", ntohs(con->http.hostaddr.sin_port));
-  if (strcmp(con->http.hostname, "localhost") == 0)
+  if (!strcmp(con->http.hostname, "localhost"))
     strlcpy(server_name, "SERVER_NAME=localhost", sizeof(server_name));
   else
     snprintf(server_name, sizeof(server_name), "SERVER_NAME=%s", ServerName);
@@ -3008,6 +3136,7 @@ pipe_command(client_t *con,		/* I - Client connection */
   else
     envp[envc ++] = "SERVER_PROTOCOL=HTTP/0.9";
   envp[envc ++] = "REDIRECT_STATUS=1";
+  envp[envc ++] = "CUPS_SERVER=localhost";
   envp[envc ++] = ipp_port;
   envp[envc ++] = server_name;
   envp[envc ++] = server_port;
@@ -3020,6 +3149,19 @@ pipe_command(client_t *con,		/* I - Client connection */
   envp[envc ++] = cups_datadir;
   envp[envc ++] = cups_serverroot;
 
+  if (getenv("VG_ARGS") != NULL)
+  {
+    snprintf(vg_args, sizeof(vg_args), "VG_ARGS=%s", getenv("VG_ARGS"));
+    envp[envc ++] = vg_args;
+  }
+
+  if (getenv("LD_ASSUME_KERNEL") != NULL)
+  {
+    snprintf(ld_assume_kernel, sizeof(ld_assume_kernel), "LD_ASSUME_KERNEL=%s",
+             getenv("LD_ASSUME_KERNEL"));
+    envp[envc ++] = ld_assume_kernel;
+  }
+
   if (getenv("LD_LIBRARY_PATH") != NULL)
   {
     snprintf(ld_library_path, sizeof(ld_library_path), "LD_LIBRARY_PATH=%s",
@@ -3156,15 +3298,20 @@ pipe_command(client_t *con,		/* I - Client connection */
       if (setgid(Group))
         exit(errno);
 
+      if (setgroups(1, &Group))
+        exit(errno);
+
       if (setuid(User))
         exit(errno);
     }
+    else
+    {
+     /*
+      * Reset group membership to just the main one we belong to.
+      */
 
-   /*
-    * Reset group membership to just the main one we belong to.
-    */
-
-    setgroups(0, NULL);
+      setgroups(1, &Group);
+    }
 
    /*
     * Update stdin/stdout/stderr...
@@ -3309,5 +3456,5 @@ CDSAWriteFunc(SSLConnectionRef connection,	/* I  - SSL/TLS connection */
 
 
 /*
- * End of "$Id: client.c,v 1.160 2003/05/09 16:10:22 mike Exp $".
+ * End of "$Id: client.c,v 1.175 2003/09/29 14:51:20 mike Exp $".
  */
