@@ -1,5 +1,5 @@
 /*
- * "$Id: client.h,v 1.26 2003/03/31 16:31:36 mike Exp $"
+ * "$Id: client.h,v 1.27 2003/07/20 02:51:54 mike Exp $"
  *
  *   Client definitions for the Common UNIX Printing System (CUPS) scheduler.
  *
@@ -66,7 +66,10 @@ typedef struct
  * Globals...
  */
 
-VAR int			ListenBackLog	VALUE(SOMAXCONN);
+VAR int			ListenBackLog	VALUE(SOMAXCONN),
+					/* Max backlog of pending connections */
+			LocalPort	VALUE(631);
+					/* Local port to use */
 VAR int			NumListeners	VALUE(0);
 					/* Number of listening sockets */
 VAR listener_t		*Listeners	VALUE(NULL);
@@ -106,5 +109,5 @@ extern void	UpdateCGI(void);
 extern int	WriteClient(client_t *con);
 
 /*
- * End of "$Id: client.h,v 1.26 2003/03/31 16:31:36 mike Exp $".
+ * End of "$Id: client.h,v 1.27 2003/07/20 02:51:54 mike Exp $".
  */
