@@ -1,5 +1,5 @@
 /*
- * "$Id: conf.c,v 1.134 2003/04/23 18:55:12 mike Exp $"
+ * "$Id: conf.c,v 1.140 2003/11/07 19:41:25 mike Exp $"
  *
  *   Configuration routines for the Common UNIX Printing System (CUPS).
  *
@@ -59,37 +59,6 @@
 #endif /* !INADDR_NONE */
 
 
-/*
- * Some OS's don't have hstrerror(), most notably Solaris...
- */
-
-#ifndef HAVE_HSTRERROR
-const char *					/* O - Error string */
-cups_hstrerror(int error)			/* I - Error number */
-{
-  static const char * const errors[] =
-		{
-		  "OK",
-		  "Host not found.",
-		  "Try again.",
-		  "Unrecoverable lookup error.",
-		  "No data associated with name."
-		};
-
-
-  if (error < 0 || error > 4)
-    return ("Unknown hostname lookup error.");
-  else
-    return (errors[error]);
-}
-#elif defined(_AIX)
-/*
- * AIX doesn't provide a prototype but does provide the function...
- */
-extern const char *hstrerror(int);
-#endif /* !HAVE_HSTRERROR */
-
-
 /*
  * Configuration variable structure...
  */
@@ -453,6 +422,12 @@ ReadConfiguration(void)
 
   LogMessage(L_INFO, "Loaded configuration file \"%s\"", ConfigurationFile);
 
+ /*
+  * Set the default locale using the language and charset...
+  */
+
+  SetStringf(&DefaultLocale, "%s.%s", DefaultLanguage, DefaultCharset);
+
  /*
   * Update all relative filenames to include the full path from ServerRoot...
   */
@@ -867,6 +842,8 @@ read_configuration(cups_file_t *fp)	/* I - File to read from */
       Listeners = temp;
       temp      += NumListeners;
 
+      memset(temp, 0, sizeof(listener_t));
+
       if (get_address(value, INADDR_ANY, IPP_PORT, &(temp->address)))
       {
         LogMessage(L_INFO, "Listening to %x:%d",
@@ -1150,6 +1127,13 @@ read_configuration(cups_file_t *fp)	/* I - File to read from */
 	  else
 	    netmask = netmasks[ipcount - 1];
 
+          if ((address & ~netmask) != 0)
+	  {
+	    LogMessage(L_WARN, "Discarding extra bits in %s address %08x for netmask %08x...",
+	               name, address, netmask);
+            address &= netmask;
+	  }
+
           if (strcasecmp(name, "BrowseAllow") == 0)
 	    AllowIP(location, address, netmask);
 	  else
@@ -1834,6 +1818,13 @@ read_location(cups_file_t *fp,		/* I - Configuration file */
 	else
 	  netmask = netmasks[ipcount - 1];
 
+        if ((address & ~netmask) != 0)
+	{
+	  LogMessage(L_WARN, "Discarding extra bits in %s address %08x for netmask %08x...",
+	             name, address, netmask);
+          address &= netmask;
+	}
+
         if (strcasecmp(name, "Allow") == 0)
 	  AllowIP(loc, address, netmask);
 	else
@@ -2032,7 +2023,7 @@ get_address(char               *value,		/* I - Value string */
   * Decode the hostname and port number as needed...
   */
 
-  if (hostname[0] && strcmp(hostname, "*") != 0)
+  if (hostname[0] && strcmp(hostname, "*"))
   {
     if ((host = httpGetHostByName(hostname)) == NULL)
     {
@@ -2156,5 +2147,5 @@ CDSAGetServerCerts(void)
 
 
 /*
- * End of "$Id: conf.c,v 1.134 2003/04/23 18:55:12 mike Exp $".
+ * End of "$Id: conf.c,v 1.140 2003/11/07 19:41:25 mike Exp $".
  */
