@@ -1,5 +1,5 @@
 /*
- * "$Id: conf.h,v 1.56 2003/03/30 19:50:34 mike Exp $"
+ * "$Id: conf.h,v 1.60 2003/10/09 19:13:30 mike Exp $"
  *
  *   Configuration file definitions for the Common UNIX Printing System (CUPS)
  *   scheduler.
@@ -84,6 +84,8 @@ VAR char		*SystemGroups[MAX_SYSTEM_GROUPS],
 					/* Default language encoding */
 			*DefaultCharset		VALUE(NULL),
 					/* Default charset */
+			*DefaultLocale		VALUE(NULL),
+					/* Default locale */
 			*RIPCache		VALUE(NULL),
 					/* Amount of memory for RIPs */
 			*TempDir		VALUE(NULL),
@@ -98,16 +100,16 @@ VAR char		*SystemGroups[MAX_SYSTEM_GROUPS],
 					/* Remote root user */
 			*Classification		VALUE(NULL);
 					/* Classification of system */
+VAR uid_t		User			VALUE(1);
+					/* User ID for server */
+VAR gid_t		Group			VALUE(0);
+					/* Group ID for server */
 VAR int			ClassifyOverride	VALUE(0),
 					/* Allow overrides? */
 			ConfigFilePerm		VALUE(0600),
 					/* Permissions for config files */
 			LogFilePerm		VALUE(0644),
 					/* Permissions for log files */
-			User			VALUE(1),
-					/* User ID for server */
-			Group			VALUE(0),
-					/* Group ID for server */
 			LogLevel		VALUE(L_ERROR),
 					/* Log level */
 			MaxClients		VALUE(0),
@@ -192,5 +194,5 @@ extern int	LogPage(job_t *job, const char *page);
 
 
 /*
- * End of "$Id: conf.h,v 1.56 2003/03/30 19:50:34 mike Exp $".
+ * End of "$Id: conf.h,v 1.60 2003/10/09 19:13:30 mike Exp $".
  */
