@@ -1,5 +1,5 @@
 /*
- * "$Id: cupsd.h,v 1.47 2003/04/10 20:14:05 mike Exp $"
+ * "$Id: cupsd.h,v 1.51 2003/09/02 20:30:47 mike Exp $"
  *
  *   Main header file for the Common UNIX Printing System (CUPS) scheduler.
  *
@@ -22,21 +22,13 @@
  *         WWW: http://www.cups.org
  */
 
-#ifdef __sun
-/*
- * Define FD_SETSIZE to 2048 on Solaris to get the correct version of
- * select() for large numbers of file descriptors.
- */
-
-#  define FD_SETSIZE	2048
-#endif /* __sun */
-
 
 /*
  * Include necessary headers.
  */
 
-#include <stdio.h>
+#include <cups/http-private.h>
+#include <cups/string.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <errno.h>
@@ -56,7 +48,6 @@
 #endif /* WIN32 */
 
 #include <cups/cups.h>
-#include <cups/string.h>
 #include "mime.h"
 #include <cups/http.h>
 #include <cups/ipp.h>
@@ -184,8 +175,13 @@ VAR int			MaxFDs,		/* Maximum number of files */
 VAR fd_set		*InputSet,	/* Input files for select() */
 			*OutputSet;	/* Output files for select() */
 
-VAR int			NeedReload	VALUE(RELOAD_ALL);
+VAR time_t		ReloadTime	VALUE(0);
+					/* Time of reload request... */
+VAR int			NeedReload	VALUE(RELOAD_ALL),
 					/* Need to load configuration? */
+			SignalCount	VALUE(0);
+					/* Signal handler level */
+
 VAR char		*TZ		VALUE(NULL);
 					/* Timezone configuration */
 
@@ -213,5 +209,5 @@ extern void	StopServer(void);
 
 
 /*
- * End of "$Id: cupsd.h,v 1.47 2003/04/10 20:14:05 mike Exp $".
+ * End of "$Id: cupsd.h,v 1.51 2003/09/02 20:30:47 mike Exp $".
  */
