@@ -1,5 +1,5 @@
 /*
- * "$Id: dirsvc.c,v 1.115 2003/05/12 20:51:53 mike Exp $"
+ * "$Id: dirsvc.c,v 1.126 2003/10/22 14:41:33 mike Exp $"
  *
  *   Directory services routines for the Common UNIX Printing System (CUPS).
  *
@@ -302,19 +302,19 @@ ProcessBrowseData(const char   *uri,	/* I - URI of printer/class */
     update  = 1;
   }
 
-  if (!p->location || strcmp(p->location, location))
+  if (location && (!p->location || strcmp(p->location, location)))
   {
     SetString(&p->location, location);
     update = 1;
   }
 
-  if (!p->info || strcmp(p->info, info))
+  if (info && (!p->info || strcmp(p->info, info)))
   {
     SetString(&p->info, info);
     update = 1;
   }
 
-  if (!make_model[0])
+  if (!make_model || !make_model[0])
   {
     if (type & CUPS_PRINTER_CLASS)
       snprintf(local_make_model, sizeof(local_make_model),
@@ -781,6 +781,8 @@ StartBrowsing(void)
 
     FD_SET(BrowseSocket, InputSet);
   }
+  else
+    BrowseSocket = -1;
 
 #ifdef HAVE_LIBSLP
   if (BrowseProtocols & BROWSE_SLP)
@@ -886,15 +888,20 @@ StartPolling(void)
 	if (setgid(Group))
           exit(errno);
 
+	if (setgroups(1, &Group))
+          exit(errno);
+
 	if (setuid(User))
           exit(errno);
       }
+      else
+      {
+       /*
+	* Reset group membership to just the main one we belong to.
+	*/
 
-     /*
-      * Reset group membership to just the main one we belong to.
-      */
-
-      setgroups(0, NULL);
+	setgroups(1, &Group);
+      }
 
      /*
       * Redirect stdin and stdout to /dev/null, and stderr to the
@@ -1001,7 +1008,7 @@ StopBrowsing(void)
         	 BrowseSocket);
 
       FD_CLR(BrowseSocket, InputSet);
-      BrowseSocket = 0;
+      BrowseSocket = -1;
     }
   }
 
@@ -1362,7 +1369,7 @@ UpdatePolling(void)
     * Copy over the buffer data we've used up...
     */
 
-    strcpy(buffer, lineptr);
+    cups_strcpy(buffer, lineptr);
     bufused -= lineptr - buffer;
 
     if (bufused < 0)
@@ -1502,12 +1509,11 @@ SendSLPBrowse(printer_t *p)		/* I - Printer to register */
     strcpy(finishings, "none");
 
  /*
-  * Quote any commas in the make and model, location, and info strings
-  * (local strings are twice the size of the ones in the printer_t
-  * structure, so no buffer overflow is possible...)
+  * Quote any commas in the make and model, location, and info strings...
   */
 
-  for (src = p->make_model, dst = make_model; *src;)
+  for (src = p->make_model, dst = make_model;
+       src && *src && dst < (make_model + sizeof(make_model) - 2);)
   {
     if (*src == ',' || *src == '\\' || *src == ')')
       *dst++ = '\\';
@@ -1520,7 +1526,8 @@ SendSLPBrowse(printer_t *p)		/* I - Printer to register */
   if (!make_model[0])
     strcpy(make_model, "Unknown");
 
-  for (src = p->location, dst = location; *src;)
+  for (src = p->location, dst = location;
+       src && *src && dst < (location + sizeof(location) - 2);)
   {
     if (*src == ',' || *src == '\\' || *src == ')')
       *dst++ = '\\';
@@ -1533,7 +1540,8 @@ SendSLPBrowse(printer_t *p)		/* I - Printer to register */
   if (!location[0])
     strcpy(location, "Unknown");
 
-  for (src = p->info, dst = info; *src;)
+  for (src = p->info, dst = info;
+       src && *src && dst < (info + sizeof(info) - 2);)
   {
     if (*src == ',' || *src == '\\' || *src == ')')
       *dst++ = '\\';
@@ -1636,14 +1644,13 @@ SLPDeregPrinter(printer_t *p)
 int 					/* O - 0 on success */
 GetSlpAttrVal(const char *attrlist,	/* I - Attribute list string */
               const char *tag,		/* I - Name of attribute */
-              char       *valbuf,	/* O - Value */
-              int        valbuflen)	/* I - Max length of value */
+              char       **valbuf)	/* O - Value */
 {
   char	*ptr1,				/* Pointer into string */
 	*ptr2;				/* ... */
 
 
-  valbuf[0] = '\0';
+  ClearString(valbuf);
 
   if ((ptr1 = strstr(attrlist, tag)) != NULL)
   {
@@ -1651,25 +1658,22 @@ GetSlpAttrVal(const char *attrlist,	/* I - Attribute list string */
 
     if ((ptr2 = strchr(ptr1,')')) != NULL)
     {
-      if (valbuflen > (ptr2 - ptr1))
-      {
-       /*
-        * Copy the value...
-	*/
+     /*
+      * Copy the value...
+      */
 
-        strncpy(valbuf, ptr1, ptr2 - ptr1);
-	valbuf[ptr2 - ptr1] = '\0';
+      *valbuf = calloc(ptr2 - ptr1 + 1, 1);
+      strncpy(*valbuf, ptr1, ptr2 - ptr1);
 
-       /*
-        * Dequote the value...
-	*/
+     /*
+      * Dequote the value...
+      */
 
-	for (ptr1 = valbuf; *ptr1; ptr1 ++)
-	  if (*ptr1 == '\\' && ptr1[1])
-	    strcpy(ptr1, ptr1 + 1);
+      for (ptr1 = *valbuf; *ptr1; ptr1 ++)
+	if (*ptr1 == '\\' && ptr1[1])
+	  cups_strcpy(ptr1, ptr1 + 1);
 
-        return (0);
-      }
+      return (0);
     }
   }
 
@@ -1681,13 +1685,13 @@ GetSlpAttrVal(const char *attrlist,	/* I - Attribute list string */
  * 'AttrCallback()' - SLP attribute callback 
  */
 
-SLPBoolean
-AttrCallback(SLPHandle  hslp, 
-             const char *attrlist, 
-             SLPError   errcode, 
-             void       *cookie)
+SLPBoolean				/* O - SLP_TRUE for success */
+AttrCallback(SLPHandle  hslp,		/* I - SLP handle */
+             const char *attrlist,	/* I - Attribute list */
+             SLPError   errcode,	/* I - Parsing status for this attr */
+             void       *cookie)	/* I - Current printer */
 {
-  char         tmp[IPP_MAX_NAME];
+  char         *tmp = 0;
   printer_t    *p = (printer_t*)cookie;
 
 
@@ -1712,19 +1716,19 @@ AttrCallback(SLPHandle  hslp,
 
   p->type = CUPS_PRINTER_REMOTE;
 
-  if (GetSlpAttrVal(attrlist, "(printer-location=", p->location,
-                    sizeof(p->location)))
+  if (GetSlpAttrVal(attrlist, "(printer-location=", &(p->location)))
     return (SLP_FALSE);
-  if (GetSlpAttrVal(attrlist, "(printer-make-and-model=", p->make_model,
-                    sizeof(p->make_model)))
+  if (GetSlpAttrVal(attrlist, "(printer-info=", &(p->info)))
+    return (SLP_FALSE);
+  if (GetSlpAttrVal(attrlist, "(printer-make-and-model=", &(p->make_model)))
     return (SLP_FALSE);
 
-  if (GetSlpAttrVal(attrlist, "(color-supported=", tmp, sizeof(tmp)))
+  if (GetSlpAttrVal(attrlist, "(color-supported=", &tmp))
     return (SLP_FALSE);
   if (strcasecmp(tmp, "true") == 0)
     p->type |= CUPS_PRINTER_COLOR;
 
-  if (GetSlpAttrVal(attrlist, "(finishings-supported=", tmp, sizeof(tmp)))
+  if (GetSlpAttrVal(attrlist, "(finishings-supported=", &tmp))
     return (SLP_FALSE);
   if (strstr(tmp, "staple"))
     p->type |= CUPS_PRINTER_STAPLE;
@@ -1733,11 +1737,13 @@ AttrCallback(SLPHandle  hslp,
   if (strstr(tmp, "punch"))
     p->type |= CUPS_PRINTER_PUNCH;
 
-  if (GetSlpAttrVal(attrlist, "(sides-supported=", tmp, sizeof(tmp)))
+  if (GetSlpAttrVal(attrlist, "(sides-supported=", &tmp))
     return (SLP_FALSE);
   if (strstr(tmp,"two-sided"))
     p->type |= CUPS_PRINTER_DUPLEX;
 
+  ClearString(&tmp);
+
   return (SLP_TRUE);
 }
 
@@ -1900,5 +1906,5 @@ UpdateSLPBrowse(void)
 
 
 /*
- * End of "$Id: dirsvc.c,v 1.115 2003/05/12 20:51:53 mike Exp $".
+ * End of "$Id: dirsvc.c,v 1.126 2003/10/22 14:41:33 mike Exp $".
  */
