@@ -1,5 +1,5 @@
 /*
- * "$Id: file.c,v 1.3 2003/04/10 12:57:44 mike Exp $"
+ * "$Id: file.c,v 1.5 2003/11/04 16:37:44 mike Exp $"
  *
  *   File functions for the Common UNIX Printing System (CUPS).
  *
@@ -535,6 +535,7 @@ cupsFileSeek(cups_file_t *fp,		/* I - CUPS file */
       fp->pos = 0;
       fp->ptr = NULL;
       fp->end = NULL;
+      fp->eof = 0;
 
       while ((bytes = cups_fill(fp)) > 0)
         if (pos >= fp->pos && pos < (fp->pos + bytes))
@@ -550,6 +551,7 @@ cupsFileSeek(cups_file_t *fp,		/* I - CUPS file */
       fp->pos = pos;
       fp->ptr = NULL;
       fp->end = NULL;
+      fp->eof = 0;
     }
   }
   else if (pos >= (fp->pos + bytes))
@@ -830,7 +832,7 @@ cups_fill(cups_file_t *fp)		/* I - CUPS file */
     * Decompress data from the buffer...
     */
 
-    fp->stream.next_out  = fp->buf;
+    fp->stream.next_out  = (Bytef *)fp->buf;
     fp->stream.avail_out = sizeof(fp->buf);
 
     if (inflate(&(fp->stream), Z_NO_FLUSH) == Z_STREAM_END)
@@ -969,5 +971,5 @@ cups_write(int        fd,		/* I - File descriptor */
 
 
 /*
- * End of "$Id: file.c,v 1.3 2003/04/10 12:57:44 mike Exp $".
+ * End of "$Id: file.c,v 1.5 2003/11/04 16:37:44 mike Exp $".
  */
