@@ -1,5 +1,5 @@
 /*
- * "$Id: job.c,v 1.211 2003/05/12 15:09:42 mike Exp $"
+ * "$Id: job.c,v 1.222 2003/11/05 19:11:42 mike Exp $"
  *
  *   Job management routines for the Common UNIX Printing System (CUPS).
  *
@@ -53,6 +53,7 @@
  *   ipp_length()         - Compute the size of the buffer needed to hold 
  *		            the textual IPP attributes.
  *   start_process()      - Start a background process.
+ *   set_hold_until()     - Set the hold time and update job-hold-until attribute.
  */
 
 /*
@@ -85,6 +86,7 @@ static void		set_time(job_t *job, const char *name);
 static int		start_process(const char *command, char *argv[],
 			              char *envp[], int in, int out, int err,
 				      int root, int *pid);
+static void		set_hold_until(job_t *job, time_t holdtime);
 
 
 /*
@@ -296,7 +298,7 @@ CheckJobs(void)
     * Start pending jobs if the destination is available...
     */
 
-    if (current->state->values[0].integer == IPP_JOB_PENDING)
+    if (current->state->values[0].integer == IPP_JOB_PENDING && !NeedReload)
     {
       if ((pclass = FindClass(current->dest)) != NULL)
       {
@@ -556,7 +558,7 @@ LoadAllJobs(void)
   */
 
   while ((dent = readdir(dir)) != NULL)
-    if (NAMLEN(dent) == 6 && dent->d_name[0] == 'c')
+    if (NAMLEN(dent) >= 6 && dent->d_name[0] == 'c')
     {
      /*
       * Allocate memory for the job...
@@ -689,10 +691,26 @@ LoadAllJobs(void)
                                          IPP_TAG_INTEGER);
       job->job_sheets = ippFindAttribute(job->attrs, "job-sheets", IPP_TAG_NAME);
 
-      attr = ippFindAttribute(job->attrs, "job-priority", IPP_TAG_INTEGER);
+      if ((attr = ippFindAttribute(job->attrs, "job-priority", IPP_TAG_INTEGER)) == NULL)
+      {
+        LogMessage(L_ERROR, "LoadAllJobs: Missing or bad job-priority attribute in control file \"%s\"!",
+	           filename);
+	ippDelete(job->attrs);
+	free(job);
+	unlink(filename);
+	continue;
+      }
       job->priority = attr->values[0].integer;
 
-      attr = ippFindAttribute(job->attrs, "job-originating-user-name", IPP_TAG_NAME);
+      if ((attr = ippFindAttribute(job->attrs, "job-originating-user-name", IPP_TAG_NAME)) == NULL)
+      {
+        LogMessage(L_ERROR, "LoadAllJobs: Missing or bad job-originating-user-name attribute in control file \"%s\"!",
+	           filename);
+	ippDelete(job->attrs);
+	free(job);
+	unlink(filename);
+	continue;
+      }
       SetString(&job->username, attr->values[0].string.text);
 
      /*
@@ -740,14 +758,14 @@ LoadAllJobs(void)
   rewinddir(dir);
 
   while ((dent = readdir(dir)) != NULL)
-    if (NAMLEN(dent) > 7 && dent->d_name[0] == 'd')
+    if (NAMLEN(dent) > 7 && dent->d_name[0] == 'd' && strchr(dent->d_name, '-'))
     {
      /*
       * Find the job...
       */
 
       jobid  = atoi(dent->d_name + 1);
-      fileid = atoi(dent->d_name + 7);
+      fileid = atoi(strchr(dent->d_name, '-') + 1);
 
       LogMessage(L_DEBUG, "LoadAllJobs: Auto-typing document file %s...",
                  dent->d_name);
@@ -833,7 +851,7 @@ MoveJob(int        id,		/* I - Job ID */
 
       SetString(&current->dest, dest);
       current->dtype = p->type & (CUPS_PRINTER_CLASS | CUPS_PRINTER_REMOTE |
-                                  CUPS_PRINTER_IMPLICIT | CUPS_PRINTER_FAX);
+                                  CUPS_PRINTER_IMPLICIT);
 
       if ((attr = ippFindAttribute(current->attrs, "job-printer-uri", IPP_TAG_URI)) != NULL)
       {
@@ -922,7 +940,7 @@ SaveJob(int id)			/* I - Job ID */
   }
 
   fchmod(fd, 0600);
-  fchown(fd, User, Group);
+  fchown(fd, getuid(), Group);
 
   ippWriteFile(fd, job->attrs);
 
@@ -1175,6 +1193,7 @@ StartJob(int       id,			/* I - Job ID */
 		processPath[1050],	/* CFProcessPath environment variable */
 #endif	/* __APPLE__ */
 		path[1024],		/* PATH environment variable */
+		ipp_port[1024],		/* IPP_PORT environment variable */
 		language[255],		/* LANG environment variable */
 		charset[255],		/* CHARSET environment variable */
 		classification[1024],	/* CLASSIFICATION environment variable */
@@ -1192,7 +1211,9 @@ StartJob(int       id,			/* I - Job ID */
 		shlib_path[1024],	/* SHLIB_PATH environment variable */
 		nlspath[1024],		/* NLSPATH environment variable */
 		datadir[1024],		/* CUPS_DATADIR environment variable */
-		fontpath[1050];		/* CUPS_FONTPATH environment variable */
+		fontpath[1050],		/* CUPS_FONTPATH environment variable */
+		vg_args[1024],		/* VG_ARGS environment variable */
+		ld_assume_kernel[1024];	/* LD_ASSUME_KERNEL environment variable */
   static char	*options = NULL;	/* Full list of options */
   static int	optlength = 0;		/* Length of option buffer */
 
@@ -1681,6 +1702,7 @@ StartJob(int       id,			/* I - Job ID */
   snprintf(tmpdir, sizeof(tmpdir), "TMPDIR=%s", TempDir);
   snprintf(datadir, sizeof(datadir), "CUPS_DATADIR=%s", DataDir);
   snprintf(fontpath, sizeof(fontpath), "CUPS_FONTPATH=%s", FontPath);
+  sprintf(ipp_port, "IPP_PORT=%d", LocalPort);
 
   envc = 0;
 
@@ -1689,7 +1711,8 @@ StartJob(int       id,			/* I - Job ID */
   envp[envc ++] = "USER=root";
   envp[envc ++] = charset;
   envp[envc ++] = language;
-  envp[envc ++] = TZ;
+  if (TZ && TZ[0])
+    envp[envc ++] = TZ;
   envp[envc ++] = ppd;
   envp[envc ++] = root;
   envp[envc ++] = cache;
@@ -1699,6 +1722,21 @@ StartJob(int       id,			/* I - Job ID */
   envp[envc ++] = printer_name;
   envp[envc ++] = datadir;
   envp[envc ++] = fontpath;
+  envp[envc ++] = "CUPS_SERVER=localhost";
+  envp[envc ++] = ipp_port;
+
+  if (getenv("VG_ARGS") != NULL)
+  {
+    snprintf(vg_args, sizeof(vg_args), "VG_ARGS=%s", getenv("VG_ARGS"));
+    envp[envc ++] = vg_args;
+  }
+
+  if (getenv("LD_ASSUME_KERNEL") != NULL)
+  {
+    snprintf(ld_assume_kernel, sizeof(ld_assume_kernel), "LD_ASSUME_KERNEL=%s",
+             getenv("LD_ASSUME_KERNEL"));
+    envp[envc ++] = ld_assume_kernel;
+  }
 
   if (getenv("LD_LIBRARY_PATH") != NULL)
   {
@@ -2006,7 +2044,8 @@ StopJob(int id,			/* I - Job ID */
         FilterLevel -= current->cost;
 
         if (current->status < 0 &&
-	    !(current->dtype & (CUPS_PRINTER_CLASS | CUPS_PRINTER_IMPLICIT)))
+	    !(current->dtype & (CUPS_PRINTER_CLASS | CUPS_PRINTER_IMPLICIT)) &&
+	    !(current->printer->type & CUPS_PRINTER_FAX))
 	  SetPrinterState(current->printer, IPP_PRINTER_STOPPED, 1);
 	else if (current->printer->state != IPP_PRINTER_STOPPED)
 	  SetPrinterState(current->printer, IPP_PRINTER_IDLE, 0);
@@ -2071,6 +2110,7 @@ UpdateJob(job_t *job)		/* I - Job to check */
 		*message;	/* Pointer to message text */
   int		loglevel;	/* Log level for message */
   int		job_history;	/* Did CancelJob() keep the job? */
+  cups_ptype_t	ptype;		/* Printer type (color, small, etc.) */
 
 
   if ((bytes = read(job->pipe, job->buffer + job->bufused,
@@ -2232,7 +2272,7 @@ UpdateJob(job_t *job)		/* I - Job to check */
     * Copy over the buffer data we've used up...
     */
 
-    strcpy(job->buffer, lineptr);
+    cups_strcpy(job->buffer, lineptr);
     job->bufused -= lineptr - job->buffer;
 
     if (job->bufused < 0)
@@ -2266,6 +2306,8 @@ UpdateJob(job_t *job)		/* I - Job to check */
       * Backend had errors; stop it...
       */
 
+      ptype = job->printer->type;
+
       StopJob(job->id, 0);
       job->state->values[0].integer = IPP_JOB_PENDING;
       SaveJob(job->id);
@@ -2277,7 +2319,7 @@ UpdateJob(job_t *job)		/* I - Job to check */
 
       if (job->dtype & (CUPS_PRINTER_CLASS | CUPS_PRINTER_IMPLICIT))
         CheckJobs();
-      else if (job->dtype & CUPS_PRINTER_FAX)
+      else if (ptype & CUPS_PRINTER_FAX)
       {
        /*
         * See how many times we've tried to send the job; if more than
@@ -2302,8 +2344,7 @@ UpdateJob(job_t *job)		/* I - Job to check */
 	  * Try again in N seconds...
 	  */
 
-          job->state->values[0].integer = IPP_JOB_HELD;
-	  job->hold_until               = time(NULL) + FaxRetryInterval;
+	  set_hold_until(job, time(NULL) + FaxRetryInterval);
 	}
 
         CheckJobs();
@@ -2578,15 +2619,20 @@ start_process(const char *command,	/* I - Full path to command */
       if (setgid(Group))
         exit(errno);
 
+      if (setgroups(1, &Group))
+        exit(errno);
+
       if (setuid(User))
         exit(errno);
     }
+    else
+    {
+     /*
+      * Reset group membership to just the main one we belong to.
+      */
 
-   /*
-    * Reset group membership to just the main one we belong to.
-    */
-
-    setgroups(0, NULL);
+      setgroups(1, &Group);
+    }
 
    /*
     * Change umask to restrict permissions on created files...
@@ -2645,5 +2691,53 @@ start_process(const char *command,	/* I - Full path to command */
 
 
 /*
- * End of "$Id: job.c,v 1.211 2003/05/12 15:09:42 mike Exp $".
+ * 'set_hold_until()' - Set the hold time and update job-hold-until attribute...
+ */
+
+static void 
+set_hold_until(job_t *job, 		/* I - Job to update */
+	       time_t holdtime)		/* I - Hold until time */
+{
+  ipp_attribute_t	*attr;		/* job-hold-until attribute */
+  struct tm		*holddate;	/* Hold date */
+  char			holdstr[64];	/* Hold time */
+
+
+ /*
+  * Set the hold_until value and hold the job...
+  */
+
+  LogMessage(L_DEBUG, "set_hold_until: hold_until = %d", (int)holdtime);
+
+  job->state->values[0].integer = IPP_JOB_HELD;
+  job->hold_until               = holdtime;
+
+ /*
+  * Update the job-hold-until attribute with a string representing GMT
+  * time (HH:MM:SS)...
+  */
+
+  holddate = gmtime(&holdtime);
+  snprintf(holdstr, sizeof(holdstr), "%d:%d:%d", holddate->tm_hour, 
+	   holddate->tm_min, holddate->tm_sec);
+
+  if ((attr = ippFindAttribute(job->attrs, "job-hold-until", IPP_TAG_KEYWORD)) == NULL)
+    attr = ippFindAttribute(job->attrs, "job-hold-until", IPP_TAG_NAME);
+
+ /*
+  * Either add the attribute or update the value of the existing one
+  */
+
+  if (attr == NULL)
+    attr = ippAddString(job->attrs, IPP_TAG_JOB, IPP_TAG_KEYWORD,
+                        "job-hold-until", NULL, holdstr);
+  else
+    SetString(&attr->values[0].string.text, holdstr);
+
+  SaveJob(job->id);
+}
+
+
+/*
+ * End of "$Id: job.c,v 1.222 2003/11/05 19:11:42 mike Exp $".
  */
