@@ -1,5 +1,5 @@
 /*
- * "$Id: log.c,v 1.32 2003/04/10 20:14:06 mike Exp $"
+ * "$Id: log.c,v 1.38 2003/10/09 19:13:30 mike Exp $"
  *
  *   Log file routines for the Common UNIX Printing System (CUPS).
  *
@@ -57,6 +57,7 @@ char *				/* O - Date/time string */
 GetDateTime(time_t t)		/* I - Time value */
 {
   struct tm	*date;		/* Date/time value */
+  static time_t	last_time = -1;	/* Last time value */
   static char	s[1024];	/* Date/time string */
   static const char * const months[12] =
 		{		/* Months */
@@ -75,31 +76,36 @@ GetDateTime(time_t t)		/* I - Time value */
 		};
 
 
- /*
-  * Get the date and time from the UNIX time value, and then format it
-  * into a string.  Note that we *can't* use the strftime() function since
-  * it is localized and will seriously confuse automatic programs if the
-  * month names are in the wrong language!
-  *
-  * Also, we use the "timezone" variable that contains the current timezone
-  * offset from GMT in seconds so that we are reporting local time in the
-  * log files.  If you want GMT, set the TZ environment variable accordingly
-  * before starting the scheduler.
-  *
-  * (*BSD and Darwin store the timezone offset in the tm structure)
-  */
+  if (t != last_time)
+  {
+    last_time = t;
 
-  date = localtime(&t);
+   /*
+    * Get the date and time from the UNIX time value, and then format it
+    * into a string.  Note that we *can't* use the strftime() function since
+    * it is localized and will seriously confuse automatic programs if the
+    * month names are in the wrong language!
+    *
+    * Also, we use the "timezone" variable that contains the current timezone
+    * offset from GMT in seconds so that we are reporting local time in the
+    * log files.  If you want GMT, set the TZ environment variable accordingly
+    * before starting the scheduler.
+    *
+    * (*BSD and Darwin store the timezone offset in the tm structure)
+    */
 
-  snprintf(s, sizeof(s), "[%02d/%s/%04d:%02d:%02d:%02d %+03ld%02ld]",
-	   date->tm_mday, months[date->tm_mon], 1900 + date->tm_year,
-	   date->tm_hour, date->tm_min, date->tm_sec,
+    date = localtime(&t);
+
+    snprintf(s, sizeof(s), "[%02d/%s/%04d:%02d:%02d:%02d %+03ld%02ld]",
+	     date->tm_mday, months[date->tm_mon], 1900 + date->tm_year,
+	     date->tm_hour, date->tm_min, date->tm_sec,
 #ifdef HAVE_TM_GMTOFF
-           date->tm_gmtoff / 3600, (date->tm_gmtoff / 60) % 60);
+             date->tm_gmtoff / 3600, (date->tm_gmtoff / 60) % 60);
 #else
-           timezone / 3600, (timezone / 60) % 60);
+             timezone / 3600, (timezone / 60) % 60);
 #endif /* HAVE_TM_GMTOFF */
- 
+  }
+
   return (s);
 }
 
@@ -108,15 +114,15 @@ GetDateTime(time_t t)		/* I - Time value */
  * 'LogMessage()' - Log a message to the error log file.
  */
 
-int				/* O - 1 on success, 0 on error */
-LogMessage(int        level,	/* I - Log level */
-           const char *message,	/* I - printf-style message string */
-	   ...)			/* I - Additional args as needed */
+int					/* O - 1 on success, 0 on error */
+LogMessage(int        level,		/* I - Log level */
+           const char *message,		/* I - printf-style message string */
+	   ...)				/* I - Additional args as needed */
 {
-  int		len;		/* Length of message */
-  char		line[1024];	/* Line for output file */
-  va_list	ap;		/* Argument pointer */
-  static const char levels[] =	/* Log levels... */
+  int		len;			/* Length of message */
+  char		*ptr;			/* Pointer to message */
+  va_list	ap;			/* Argument pointer */
+  static const char levels[] =		/* Log levels... */
 		{
 		  ' ',
 		  'X',
@@ -130,7 +136,7 @@ LogMessage(int        level,	/* I - Log level */
 		  'd'
 		};
 #ifdef HAVE_VSYSLOG
-  static const int syslevels[] =/* SYSLOG levels... */
+  static const int syslevels[] =	/* SYSLOG levels... */
 		{
 		  0,
 		  LOG_EMERG,
@@ -144,6 +150,8 @@ LogMessage(int        level,	/* I - Log level */
 		  LOG_DEBUG
 		};
 #endif /* HAVE_VSYSLOG */
+  static int	linesize = 0;		/* Size of line for output file */
+  static char	*line = NULL;		/* Line for output file */
 
 
  /*
@@ -153,8 +161,6 @@ LogMessage(int        level,	/* I - Log level */
   if (level > LogLevel)
     return (1);
 
-  HoldSignals();
-
 #ifdef HAVE_VSYSLOG
  /*
   * See if we are logging errors via syslog...
@@ -166,8 +172,6 @@ LogMessage(int        level,	/* I - Log level */
     vsyslog(syslevels[level], message, ap);
     va_end(ap);
 
-    ReleaseSignals();
-
     return (1);
   }
 #endif /* HAVE_VSYSLOG */
@@ -177,11 +181,7 @@ LogMessage(int        level,	/* I - Log level */
   */
 
   if (!check_log_file(&ErrorFile, ErrorLog))
-  {
-    ReleaseSignals();
-
     return (0);
-  }
 
  /*
   * Print the log level and date/time...
@@ -190,26 +190,89 @@ LogMessage(int        level,	/* I - Log level */
   cupsFilePrintf(ErrorFile, "%c %s ", levels[level], GetDateTime(time(NULL)));
 
  /*
-  * Then the log message...
+  * Allocate the line buffer as needed...
+  */
+
+  if (!linesize)
+  {
+    linesize = 8192;
+    line     = malloc(linesize);
+
+    if (!line)
+    {
+      cupsFilePrintf(ErrorFile,
+                     "ERROR: Unable to allocate memory for line - %s\n",
+                     strerror(errno));
+      cupsFileFlush(ErrorFile);
+
+      return (0);
+    }
+  }
+
+ /*
+  * Format the log message...
   */
 
   va_start(ap, message);
-  len = vsnprintf(line, sizeof(line), message, ap);
+  len = vsnprintf(line, linesize, message, ap);
   va_end(ap);
 
+ /*
+  * Resize the buffer as needed...
+  */
+
+  if (len >= linesize)
+  {
+    len ++;
+
+    if (len < 8192)
+      len = 8192;
+    else if (len > 65536)
+      len = 65536;
+
+    line = realloc(line, len);
+
+    if (line)
+      linesize = len;
+    else
+    {
+      cupsFilePrintf(ErrorFile,
+                     "ERROR: Unable to allocate memory for line - %s\n",
+                     strerror(errno));
+      cupsFileFlush(ErrorFile);
+
+      return (0);
+    }
+
+    va_start(ap, message);
+    len = vsnprintf(line, linesize, message, ap);
+    va_end(ap);
+  }
+
+  ptr = line;
+
+  if (len >= linesize)
+    len = linesize - 1;
+
+ /*
+  * Then the log message...
+  */
+
+  cupsFilePuts(ErrorFile, line);
+
  /*
   * Then a newline...
   */
 
   if (len > 0 && line[len - 1] != '\n')
-    cupsFilePrintf(ErrorFile, "%s\n", line);
-  else
-    cupsFilePuts(ErrorFile, line);
+    cupsFilePutChar(ErrorFile, '\n');
+
+ /*
+  * Flush the line to the file and return...
+  */
 
   cupsFileFlush(ErrorFile);
 
-  ReleaseSignals();
-
   return (1);
 }
 
@@ -230,8 +293,6 @@ LogPage(job_t       *job,	/* I - Job being printed */
   hostname = ippFindAttribute(job->attrs, "job-originating-host-name",
                               IPP_TAG_ZERO);
 
-  HoldSignals();
-
 #ifdef HAVE_VSYSLOG
  /*
   * See if we are logging pages via syslog...
@@ -244,8 +305,6 @@ LogPage(job_t       *job,	/* I - Job being printed */
            job->id, page, billing ? billing->values[0].string.text : "-",
            hostname->values[0].string.text);
 
-    ReleaseSignals();
-
     return (1);
   }
 #endif /* HAVE_VSYSLOG */
@@ -255,11 +314,7 @@ LogPage(job_t       *job,	/* I - Job being printed */
   */
 
   if (!check_log_file(&PageFile, PageLog))
-  {
-    ReleaseSignals();
-
     return (0);
-  }
 
  /*
   * Print a page log entry of the form:
@@ -275,8 +330,6 @@ LogPage(job_t       *job,	/* I - Job being printed */
         	 hostname->values[0].string.text);
   cupsFileFlush(PageFile);
 
-  ReleaseSignals();
-
   return (1);
 }
 
@@ -308,8 +361,6 @@ LogRequest(client_t      *con,	/* I - Request to log */
 		};
 
 
-  HoldSignals();
-
 #ifdef HAVE_VSYSLOG
  /*
   * See if we are logging accesses via syslog...
@@ -323,8 +374,6 @@ LogRequest(client_t      *con,	/* I - Request to log */
 	   con->http.version / 100, con->http.version % 100,
 	   code, con->bytes);
 
-    ReleaseSignals();
-
     return (1);
   }
 #endif /* HAVE_VSYSLOG */
@@ -334,11 +383,7 @@ LogRequest(client_t      *con,	/* I - Request to log */
   */
 
   if (!check_log_file(&AccessFile, AccessLog))
-  {
-    ReleaseSignals();
-
     return (0);
-  }
 
  /*
   * Write a log of the request in "common log format"...
@@ -351,8 +396,6 @@ LogRequest(client_t      *con,	/* I - Request to log */
 		 code, con->bytes);
   cupsFileFlush(AccessFile);
 
-  ReleaseSignals();
-
   return (1);
 }
 
@@ -371,10 +414,10 @@ check_log_file(cups_file_t **log,	/* IO - Log file */
 
 
  /*
-  * See if we have a log file to check...
+  * See if we have a log file to check or we are handling a signal...
   */
 
-  if (log == NULL || logname == NULL || !logname[0])
+  if (log == NULL || logname == NULL || !logname[0] || SignalCount)
     return (1);
 
  /*
@@ -447,7 +490,7 @@ check_log_file(cups_file_t **log,	/* IO - Log file */
 
     if (strncmp(filename, "/dev/", 5))
     {
-      fchown(cupsFileNumber(*log), User, Group);
+      fchown(cupsFileNumber(*log), getuid(), Group);
       fchmod(cupsFileNumber(*log), LogFilePerm);
     }
   }
@@ -475,7 +518,7 @@ check_log_file(cups_file_t **log,	/* IO - Log file */
 
     if (strncmp(filename, "/dev/", 5))
     {
-      fchown(cupsFileNumber(*log), User, Group);
+      fchown(cupsFileNumber(*log), getuid(), Group);
       fchmod(cupsFileNumber(*log), LogFilePerm);
     }
   }
@@ -485,5 +528,5 @@ check_log_file(cups_file_t **log,	/* IO - Log file */
 
 
 /*
- * End of "$Id: log.c,v 1.32 2003/04/10 20:14:06 mike Exp $".
+ * End of "$Id: log.c,v 1.38 2003/10/09 19:13:30 mike Exp $".
  */
