@@ -1,5 +1,5 @@
 /*
- * "$Id: main.c,v 1.104 2003/05/09 15:11:13 mike Exp $"
+ * "$Id: main.c,v 1.112 2003/11/19 16:52:14 mike Exp $"
  *
  *   Scheduler main loop for the Common UNIX Printing System (CUPS).
  *
@@ -31,6 +31,7 @@
  *   SetString()          - Set a string value.
  *   SetStringf()         - Set a formatted string value.
  *   parent_handler()     - Catch USR1/CHLD signals...
+ *   process_children()   - Process all dead children...
  *   sigchld_handler()    - Handle 'child' signals from old processes.
  *   sighup_handler()     - Handle 'hangup' signals to reconfigure the scheduler.
  *   sigterm_handler()    - Handle 'terminate' signals that stop the scheduler.
@@ -57,6 +58,7 @@
  */
 
 static void	parent_handler(int sig);
+static void	process_children(void);
 static void	sigchld_handler(int sig);
 static void	sighup_handler(int sig);
 static void	sigterm_handler(int sig);
@@ -68,10 +70,12 @@ static void	usage(void);
  */
 
 static int	parent_signal = 0;	/* Set to signal number from child */
-static int	holdcount = 0;		/* Number of time "hold" was called */
+static int	holdcount = 0;		/* Number of times "hold" was called */
 #if defined(HAVE_SIGACTION) && !defined(HAVE_SIGSET)
 static sigset_t	holdmask;		/* Old POSIX signal mask */
 #endif /* HAVE_SIGACTION && !HAVE_SIGSET */
+static int	dead_children = 0;	/* Dead children? */
+static int	stop_scheduler = 0;	/* Should the scheduler stop? */
 
 
 /*
@@ -92,6 +96,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 			*next;		/* Next job */
   listener_t		*lis;		/* Current listener */
   time_t		activity;	/* Activity timer */
+  time_t		browse_time;	/* Next browse send time */
   time_t		senddoc_time;	/* Send-Document time */
 #ifdef HAVE_MALLINFO
   time_t		mallinfo_time;	/* Malloc information time */
@@ -103,6 +108,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 #endif /* HAVE_SIGACTION && !HAVE_SIGSET */
 #ifdef __sgi
   cups_file_t		*fp;		/* Fake lpsched lock file */
+  struct stat		statbuf;	/* Needed for checking lpsched FIFO */
 #endif /* __sgi */
 
 
@@ -290,7 +296,7 @@ main(int  argc,				/* I - Number of command-line arguments */
   * Allocate memory for the input and output sets...
   */
 
-  SetSize   = (MaxFDs + 7) / 8;
+  SetSize   = (MaxFDs + 31) / 8;
   InputSet  = (fd_set *)calloc(1, SetSize);
   OutputSet = (fd_set *)calloc(1, SetSize);
   input     = (fd_set *)calloc(1, SetSize);
@@ -401,7 +407,7 @@ main(int  argc,				/* I - Number of command-line arguments */
   if (RunAsUser)
   {
     setgid(Group);
-    setgroups(0, NULL);
+    setgroups(1, &Group);
     setuid(User);
   }
 
@@ -415,20 +421,35 @@ main(int  argc,				/* I - Number of command-line arguments */
   * Loop forever...
   */
 
+  browse_time  = time(NULL);
   senddoc_time = time(NULL);
 
 #ifdef HAVE_MALLINFO
   mallinfo_time = 0;
 #endif /* HAVE_MALLINFO */
 
-  for (;;)
+  while (!stop_scheduler)
   {
+   /*
+    * Check if there are dead children to handle...
+    */
+
+    if (dead_children)
+      process_children();
+
    /*
     * Check if we need to load the server configuration file...
     */
 
     if (NeedReload)
     {
+      job_t	*job;			/* Current job */
+
+
+     /*
+      * Close any idle clients...
+      */
+
       if (NumClients > 0)
       {
         for (i = NumClients, con = Clients; i > 0; i --, con ++)
@@ -442,11 +463,28 @@ main(int  argc,				/* I - Number of command-line arguments */
 
         PauseListening();
       }
-      else if (!ReadConfiguration())
+
+     /*
+      * Check for any active jobs...
+      */
+
+      for (job = Jobs; job; job = job->next)
+        if (job->state->values[0].integer == IPP_JOB_PROCESSING)
+	  break;
+
+     /*
+      * Restart if all clients are closed and all jobs finished, or
+      * if 60 seconds has elapsed...
+      */
+
+      if ((NumClients == 0 && !job) || (time(NULL) - ReloadTime) >= 60)
       {
-        syslog(LOG_LPR, "Unable to read configuration file \'%s\' - exiting!",
-	       ConfigurationFile);
-        break;
+        if (!ReadConfiguration())
+        {
+          syslog(LOG_LPR, "Unable to read configuration file \'%s\' - exiting!",
+		 ConfigurationFile);
+          break;
+	}
       }
     }
 
@@ -638,7 +676,11 @@ main(int  argc,				/* I - Number of command-line arguments */
         UpdateSLPBrowse();
 #endif /* HAVE_LIBSLP */
 
-      SendBrowseList();
+      if (time(NULL) > browse_time)
+      {
+        SendBrowseList();
+	browse_time = time(NULL);
+      }
     }
 
    /*
@@ -685,15 +727,35 @@ main(int  argc,				/* I - Number of command-line arguments */
   }
 
  /*
-  * If we get here something very bad happened and we need to exit
-  * immediately.
+  * Log a message based on what happened...
   */
 
-  DeleteAllCerts();
-  CloseAllClients();
-  StopListening();
+  if (stop_scheduler)
+    LogMessage(L_INFO, "Scheduler shutting down normally.");
+  else
+    LogMessage(L_ERROR, "Scheduler shutting down due to program error.");
 
-  return (1);
+ /*
+  * Close all network clients and stop all jobs...
+  */
+
+  StopServer();
+
+  StopAllJobs();
+
+#ifdef __sgi
+ /*
+  * Remove the fake IRIX lpsched lock file, but only if the existing
+  * file is not a FIFO which indicates that the real IRIX lpsched is
+  * running...
+  */
+
+  if (!stat("/var/spool/lp/FIFO", &statbuf))
+    if (!S_ISFIFO(statbuf.st_mode))
+      unlink("/var/spool/lp/SCHEDLOCK");
+#endif /* __sgi */
+
+  return (!stop_scheduler);
 }
 
 
@@ -890,26 +952,27 @@ parent_handler(int sig)		/* I - Signal */
 
 
 /*
- * 'sigchld_handler()' - Handle 'child' signals from old processes.
+ * 'process_children()' - Process all dead children...
  */
 
 static void
-sigchld_handler(int sig)	/* I - Signal number */
+process_children(void)
 {
-  int		olderrno;	/* Old errno value */
   int		status;		/* Exit status of child */
   int		pid;		/* Process ID of child */
   job_t		*job;		/* Current job */
   int		i;		/* Looping var */
 
 
-  (void)sig;
-
  /*
-  * Save the original error value (wait might overwrite it...)
+  * Reset the dead_children flag...
   */
 
-  olderrno = errno;
+  dead_children = 0;
+
+ /*
+  * Collect the exit status of some children...
+  */
 
 #ifdef HAVE_WAITPID
   while ((pid = waitpid(-1, &status, WNOHANG)) > 0)
@@ -919,7 +982,7 @@ sigchld_handler(int sig)	/* I - Signal number */
   if ((pid = wait(&status)) > 0)
 #endif /* HAVE_WAITPID */
   {
-    DEBUG_printf(("sigchld_handler: pid = %d, status = %d\n", pid, status));
+    DEBUG_printf(("process_children: pid = %d, status = %d\n", pid, status));
 
    /*
     * Ignore SIGTERM errors - that comes when a job is cancelled...
@@ -988,18 +1051,31 @@ sigchld_handler(int sig)	/* I - Signal number */
 	}
       }
   }
+}
+
+
+/*
+ * 'sigchld_handler()' - Handle 'child' signals from old processes.
+ */
+
+static void
+sigchld_handler(int sig)	/* I - Signal number */
+{
+  (void)sig;
 
  /*
-  * Restore the original error value...
+  * Flag that we have dead children...
   */
 
-  errno = olderrno;
+  dead_children = 1;
 
-#ifdef HAVE_SIGSET
-  sigset(SIGCHLD, sigchld_handler);
-#elif !defined(HAVE_SIGACTION)
+ /*
+  * Reset the signal handler as needed...
+  */
+
+#if !defined(HAVE_SIGSET) && !defined(HAVE_SIGACTION)
   signal(SIGCLD, sigchld_handler);
-#endif /* HAVE_SIGSET */
+#endif /* !HAVE_SIGSET && !HAVE_SIGACTION */
 }
 
 
@@ -1013,12 +1089,11 @@ sighup_handler(int sig)	/* I - Signal number */
   (void)sig;
 
   NeedReload = RELOAD_ALL;
+  ReloadTime = time(NULL);
 
-#ifdef HAVE_SIGSET
-  sigset(SIGHUP, sighup_handler);
-#elif !defined(HAVE_SIGACTION)
+#if !defined(HAVE_SIGSET) && !defined(HAVE_SIGACTION)
   signal(SIGHUP, sighup_handler);
-#endif /* HAVE_SIGSET */
+#endif /* !HAVE_SIGSET && !HAVE_SIGACTION */
 }
 
 
@@ -1029,40 +1104,13 @@ sighup_handler(int sig)	/* I - Signal number */
 static void
 sigterm_handler(int sig)		/* I - Signal */
 {
-#ifdef __sgi
-  struct stat	statbuf;		/* Needed for checking lpsched FIFO */
-#endif /* __sgi */
-
-
   (void)sig;	/* remove compiler warnings... */
 
  /*
-  * Log an error...
+  * Flag that we should stop and return...
   */
 
-  LogMessage(L_ERROR, "Scheduler shutting down due to SIGTERM.");
-
- /*
-  * Close all network clients and stop all jobs...
-  */
-
-  StopServer();
-
-  StopAllJobs();
-
-#ifdef __sgi
- /*
-  * Remove the fake IRIX lpsched lock file, but only if the existing
-  * file is not a FIFO which indicates that the real IRIX lpsched is
-  * running...
-  */
-
-  if (!stat("/var/spool/lp/FIFO", &statbuf))
-    if (!S_ISFIFO(statbuf.st_mode))
-      unlink("/var/spool/lp/SCHEDLOCK");
-#endif /* __sgi */
-
-  exit(1);
+  stop_scheduler = 1;
 }
 
 
@@ -1079,5 +1127,5 @@ usage(void)
 
 
 /*
- * End of "$Id: main.c,v 1.104 2003/05/09 15:11:13 mike Exp $".
+ * End of "$Id: main.c,v 1.112 2003/11/19 16:52:14 mike Exp $".
  */
