@@ -1,5 +1,5 @@
 /*
- * "$Id: ppds.c,v 1.28 2003/03/30 19:50:35 mike Exp $"
+ * "$Id: ppds.c,v 1.30 2003/09/04 14:47:49 mike Exp $"
  *
  *   PPD scanning routines for the Common UNIX Printing System (CUPS).
  *
@@ -30,7 +30,6 @@
  *   compare_names() - Compare PPD filenames for sorting.
  *   compare_ppds()  - Compare PPD file make and model names for sorting.
  *   load_ppds()     - Load PPD files recursively.
- *   ppd_gets()      - Read a line from a PPD file.
  */
 
 /*
@@ -589,7 +588,7 @@ load_ppds(const char *d,		/* I - Actual directory */
       strcpy(make_model, model_name);
 
     while (isspace(make_model[0]))
-      strcpy(make_model, make_model + 1);
+      cups_strcpy(make_model, make_model + 1);
 
     if (!make_model[0])
       continue;	/* Nope... */
@@ -599,7 +598,7 @@ load_ppds(const char *d,		/* I - Actual directory */
     */
 
     while (isspace(manufacturer[0]))
-      strcpy(manufacturer, manufacturer + 1);
+      cups_strcpy(manufacturer, manufacturer + 1);
 
     if (!manufacturer[0] || strcmp(manufacturer, "ESP") == 0)
     {
@@ -670,7 +669,7 @@ load_ppds(const char *d,		/* I - Actual directory */
       */
 
       country[0] = '_';
-      strcpy(country + 1, ptr);
+      cups_strcpy(country + 1, ptr);
     }
     else
     {
@@ -781,5 +780,5 @@ load_ppds(const char *d,		/* I - Actual directory */
 
 
 /*
- * End of "$Id: ppds.c,v 1.28 2003/03/30 19:50:35 mike Exp $".
+ * End of "$Id: ppds.c,v 1.30 2003/09/04 14:47:49 mike Exp $".
  */
