@@ -1,5 +1,5 @@
 /*
- * "$Id: printers.c,v 1.151 2003/04/26 17:09:56 mike Exp $"
+ * "$Id: printers.c,v 1.155 2003/10/29 16:53:12 mike Exp $"
  *
  *   Printer routines for the Common UNIX Printing System (CUPS).
  *
@@ -495,7 +495,7 @@ DeletePrinterFilters(printer_t *p)	/* I - Printer to remove from */
       MimeDatabase->num_filters --;
 
       if (i > 1)
-        memcpy(filter, filter + 1, sizeof(mime_filter_t) * (i - 1));
+        memmove(filter, filter + 1, sizeof(mime_filter_t) * (i - 1));
 
       filter --;
     }
@@ -843,7 +843,7 @@ SaveAllPrinters(void)
   * Restrict access to the file...
   */
 
-  fchown(cupsFileNumber(fp), User, Group);
+  fchown(cupsFileNumber(fp), getuid(), Group);
   fchmod(cupsFileNumber(fp), ConfigFilePerm);
 
  /*
@@ -957,27 +957,38 @@ SetPrinterAttrs(printer_t *p)		/* I - Printer to setup */
   ppd_attr_t	*ppdattr;		/* PPD attribute */
   ipp_attribute_t *attr;		/* Attribute data */
   ipp_value_t	*val;			/* Attribute value */
-  int		nups[] =		/* number-up-supported values */
+  static const int nups[] =		/* number-up-supported values */
 		{ 1, 2, 4, 6, 9, 16 };
-  ipp_orient_t	orients[4] =		/* orientation-requested-supported values */
+  static const ipp_orient_t orients[4] =/* orientation-requested-supported values */
 		{
 		  IPP_PORTRAIT,
 		  IPP_LANDSCAPE,
 		  IPP_REVERSE_LANDSCAPE,
 		  IPP_REVERSE_PORTRAIT
 		};
-  const char	*sides[3] =		/* sides-supported values */
+  static const char * const sides[3] =	/* sides-supported values */
 		{
 		  "one",
 		  "two-long-edge",
 		  "two-short-edge"
 		};
-  const char	*versions[] =		/* ipp-versions-supported values */
+  static const char * const holds[] =	/* job-hold-until-supported values */
+		{
+		  "no-hold",
+		  "indefinite",
+		  "day-time",
+		  "evening",
+		  "night",
+		  "second-shift",
+		  "third-shift",
+		  "weekend"
+		};
+  static const char * const versions[] =/* ipp-versions-supported values */
 		{
 		  "1.0",
 		  "1.1"
 		};
-  ipp_op_t	ops[] =			/* operations-supported values */
+  static const ipp_op_t	ops[] =		/* operations-supported values */
 		{
 		  IPP_PRINT_JOB,
 		  IPP_VALIDATE_JOB,
@@ -1008,7 +1019,7 @@ SetPrinterAttrs(printer_t *p)		/* I - Printer to setup */
 		  CUPS_GET_PPDS,
 		  IPP_RESTART_JOB
 		};
-  const char	*charsets[] =		/* charset-supported values */
+  static const char * const charsets[] =/* charset-supported values */
 		{
 		  "us-ascii",
 		  "iso-8859-1",
@@ -1038,19 +1049,17 @@ SetPrinterAttrs(printer_t *p)		/* I - Printer to setup */
 		  "koi8-r",
 		  "koi8-u",
 		};
-  const char	*compressions[] =
-		{
-#ifdef HAVE_LIBZ
-		  "none",
-		  "gzip"
-#else
+  static const char * const compressions[] =
+		{			/* document-compression-supported values */
 		  "none"
+#ifdef HAVE_LIBZ
+		  ,"gzip"
 #endif /* HAVE_LIBZ */
 		};
   int		num_finishings;
-  ipp_finish_t	finishings[5];
-  const char	*multiple_document_handling[] =
-		{
+  ipp_finish_t	finishings[5];		/* finishings-supported values */
+  static const char * const multiple_document_handling[] =
+		{			/* multiple-document-handling-supported values */
 		  "separate-documents-uncollated-copies",
 		  "separate-documents-collated-copies"
 		};
@@ -1115,6 +1124,11 @@ SetPrinterAttrs(printer_t *p)		/* I - Printer to setup */
                    "orientation-requested-supported", 4, (int *)orients);
     ippAddInteger(CommonData, IPP_TAG_PRINTER, IPP_TAG_ENUM,
                   "orientation-requested-default", IPP_PORTRAIT);
+    ippAddStrings(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
+                  "job-hold-until-supported", sizeof(holds) / sizeof(holds[0]),
+		  NULL, holds);
+    ippAddString(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
+                 "job-hold-until-default", NULL, "no-hold");
 
     if (NumBanners > 0)
     {
@@ -2380,5 +2394,5 @@ write_irix_state(printer_t *p)		/* I - Printer to update */
 
 
 /*
- * End of "$Id: printers.c,v 1.151 2003/04/26 17:09:56 mike Exp $".
+ * End of "$Id: printers.c,v 1.155 2003/10/29 16:53:12 mike Exp $".
  */
