@@ -1,5 +1,5 @@
 /*
- * "$Id: server.c,v 1.5 2002/12/17 19:00:18 swdev Exp $"
+ * "$Id: server.c,v 1.14 2003/04/10 20:14:06 mike Exp $"
  *
  *   Server start/stop routines for the Common UNIX Printing System (CUPS).
  *
@@ -31,15 +31,11 @@
  * Include necessary headers...
  */
 
+#include <cups/http-private.h>
 #include "cupsd.h"
 
 #include <grp.h>
 
-#ifdef HAVE_LIBSSL
-#  include <openssl/ssl.h>
-#  include <openssl/rand.h>
-#endif /* HAVE_LIBSSL */
-
 
 /*
  * 'StartServer()' - Start the server.
@@ -75,6 +71,14 @@ StartServer(void)
     data[i] = rand(); /* Yes, this is a poor source of random data... */
 
   RAND_seed(&data, sizeof(data));
+#elif defined(HAVE_GNUTLS)
+ /*
+  * Initialize the encryption libraries...
+  */
+
+  gnutls_global_init();
+#elif defined(HAVE_CDSASSL)
+  ServerCertificatesArray = CDSAGetServerCerts();
 #endif /* HAVE_LIBSSL */
 
  /*
@@ -84,6 +88,15 @@ StartServer(void)
   StartListening();
   StartBrowsing();
   StartPolling();
+
+ /*
+  * Create a pipe for CGI processes...
+  */
+
+  pipe(CGIPipes);
+
+  LogMessage(L_DEBUG2, "StartServer: Adding fd %d to InputSet...", CGIPipes[0]);
+  FD_SET(CGIPipes[0], InputSet);
 }
 
 
@@ -109,7 +122,35 @@ StopServer(void)
     Clients = NULL;
   }
 
-  StopAllJobs();
+#if defined(HAVE_SSL) && defined(HAVE_CDSASSL)
+ /*
+  * Free all of the certificates...
+  */
+
+  if (ServerCertificatesArray)
+  {
+    CFRelease(ServerCertificatesArray);
+    ServerCertificatesArray = NULL;
+  }
+#endif /* HAVE_SSL && HAVE_CDSASSL */
+
+ /*
+  * Close the pipe for CGI processes...
+  */
+
+  if (CGIPipes[0] >= 0)
+  {
+    close(CGIPipes[0]);
+    close(CGIPipes[1]);
+
+    LogMessage(L_DEBUG2, "StopServer: Removing fd %d from InputSet...",
+               CGIPipes[0]);
+
+    FD_CLR(CGIPipes[0], InputSet);
+
+    CGIPipes[0] = -1;
+    CGIPipes[1] = -1;
+  }
 
  /*
   * Close all log files...
@@ -117,34 +158,27 @@ StopServer(void)
 
   if (AccessFile != NULL)
   {
-    fclose(AccessFile);
+    cupsFileClose(AccessFile);
 
     AccessFile = NULL;
   }
 
   if (ErrorFile != NULL)
   {
-    fclose(ErrorFile);
+    cupsFileClose(ErrorFile);
 
     ErrorFile = NULL;
   }
 
   if (PageFile != NULL)
   {
-    fclose(PageFile);
+    cupsFileClose(PageFile);
 
     PageFile = NULL;
   }
-
- /*
-  * Clear the input and output sets...
-  */
-
-  FD_ZERO(&InputSet);
-  FD_ZERO(&OutputSet);
 }
 
 
 /*
- * End of "$Id: server.c,v 1.5 2002/12/17 19:00:18 swdev Exp $".
+ * End of "$Id: server.c,v 1.14 2003/04/10 20:14:06 mike Exp $".
  */
