@@ -1,5 +1,5 @@
 /*
- * "$Id: cupstestppd.c,v 1.22 2003/05/23 15:23:46 mike Exp $"
+ * "$Id: cupstestppd.c,v 1.26 2003/11/07 19:34:43 mike Exp $"
  *
  *   PPD test program for the Common UNIX Printing System (CUPS).
  *
@@ -93,12 +93,12 @@ main(int  argc,			/* I - Number of command-line arguments */
                                 "JCL", "PAGE", "PROLOG" };
 
 
-  setbuf(stdout, NULL);
-
  /*
   * Display PPD files for each file listed on the command-line...
   */
 
+  ppdSetConformance(PPD_CONFORM_STRICT);
+
   verbose = 0;
   ppd     = NULL;
   files   = 0;
@@ -110,7 +110,7 @@ main(int  argc,			/* I - Number of command-line arguments */
       for (opt = argv[i] + 1; *opt; opt ++)
         switch (*opt)
 	{
-	  case 'q' :
+	  case 'q' :			/* Quiet mode */
 	      if (verbose > 0)
 	      {
         	fputs("cupstestppd: The -q option is incompatible with the -v option.\n",
@@ -121,7 +121,11 @@ main(int  argc,			/* I - Number of command-line arguments */
 	      verbose --;
 	      break;
 
-	  case 'v' :
+	  case 'r' :			/* Relaxed mode */
+              ppdSetConformance(PPD_CONFORM_RELAXED);
+	      break;
+
+	  case 'v' :			/* Verbose mode */
 	      if (verbose < 0)
 	      {
         	fputs("cupstestppd: The -v option is incompatible with the -q option.\n",
@@ -421,7 +425,21 @@ main(int  argc,			/* I - Number of command-line arguments */
 
       if (ppd->manufacturer != NULL)
       {
-	if (verbose > 0)
+        if (!strncasecmp(ppd->manufacturer, "Hewlett-Packard", 15) ||
+	    !strncasecmp(ppd->manufacturer, "Hewlett Packard", 15))
+	{
+	  if (verbose >= 0)
+	  {
+	    if (!errors && !verbose)
+	      puts(" FAIL");
+
+	    puts("      **FAIL**  BAD Manufacturer (should be \"HP\")");
+	    puts("                REF: Page 211, table D.1.");
+          }
+
+	  errors ++;
+	}
+	else if (verbose > 0)
 	  puts("        PASS    Manufacturer");
       }
       else if (ppdversion >= 43)
@@ -653,6 +671,94 @@ main(int  argc,			/* I - Number of command-line arguments */
 	errors ++;
       }
 
+      if (ppd->patches != NULL && strchr(ppd->patches, '\"') &&
+          strstr(ppd->patches, "*End"))
+      {
+	if (verbose >= 0)
+	{
+	  if (!errors && !verbose)
+	    puts(" FAIL");
+
+	  puts("      **FAIL**  BAD JobPatchFile attribute in file");
+	  puts("                REF: Page 24, section 3.4.");
+        }
+
+	errors ++;
+      }
+
+     /*
+      * Check for page sizes without the corresponding ImageableArea or
+      * PaperDimension values...
+      */
+
+      if (ppd->num_sizes == 0)
+      {
+	if (verbose >= 0)
+	{
+	  if (!errors && !verbose)
+	    puts(" FAIL");
+
+	  puts("      **FAIL**  REQUIRED PageSize");
+	  puts("                REF: Page 41, section 5.");
+	  puts("                REF: Page 99, section 5.14.");
+        }
+
+	errors ++;
+      }
+      else
+      {
+	for (j = 0, size = ppd->sizes; j < ppd->num_sizes; j ++, size ++)
+	{
+	 /*
+	  * Don't check custom size...
+	  */
+
+	  if (!strcmp(size->name, "Custom"))
+	    continue;
+
+	 /*
+	  * Check for ImageableArea...
+	  */
+
+          if (size->left == 0.0 && size->bottom == 0.0 &&
+	      size->right == 0.0 && size->top == 0.0)
+	  {
+	    if (verbose >= 0)
+	    {
+	      if (!errors && !verbose)
+		puts(" FAIL");
+
+	      printf("      **FAIL**  REQUIRED ImageableArea for PageSize %s\n",
+	             size->name);
+	      puts("                REF: Page 41, section 5.");
+	      puts("                REF: Page 102, section 5.15.");
+            }
+
+	    errors ++;
+	  }
+
+	 /*
+	  * Check for PaperDimension...
+	  */
+
+          if (size->width == 0.0 && size->length == 0.0)
+	  {
+	    if (verbose >= 0)
+	    {
+	      if (!errors && !verbose)
+		puts(" FAIL");
+
+	      printf("      **FAIL**  REQUIRED PaperDimension for PageSize %s\n",
+	             size->name);
+	      puts("                REF: Page 41, section 5.");
+	      puts("                REF: Page 103, section 5.15.");
+            }
+
+	    errors ++;
+	  }
+	}
+      }
+
       if (errors)
 	status = ERROR_CONFORMANCE;
       else if (!verbose)
@@ -854,6 +960,13 @@ main(int  argc,			/* I - Number of command-line arguments */
 	printf("    num_fonts = %d\n", ppd->num_fonts);
 	for (j = 0; j < ppd->num_fonts; j ++)
 	  printf("        fonts[%d] = %s\n", j, ppd->fonts[j]);
+
+	printf("    num_attrs = %d\n", ppd->num_attrs);
+	for (j = 0; j < ppd->num_attrs; j ++)
+	  printf("        attrs[%d] = %s %s%s%s: \"%s\"\n", j,
+	         ppd->attrs[j]->name, ppd->attrs[j]->spec,
+		 ppd->attrs[j]->text[0] ? "/" : "", ppd->attrs[j]->text,
+		 ppd->attrs[j]->value ? ppd->attrs[j]->value : "(null)");
       }
 
       ppdClose(ppd);
@@ -972,13 +1085,13 @@ show_conflicts(ppd_file_t *ppd)		/* I - PPD to check */
 void
 usage(void)
 {
-  puts("Usage: cupstestppd [-q] [-v[v]] filename1.ppd[.gz] [... filenameN.ppd[.gz]]");
-  puts("       program | cupstestppd [-q] [-v[v]] -");
+  puts("Usage: cupstestppd [-q] [-r] [-v[v]] filename1.ppd[.gz] [... filenameN.ppd[.gz]]");
+  puts("       program | cupstestppd [-q] [-r] [-v[v]] -");
 
   exit(ERROR_USAGE);
 }
 
 
 /*
- * End of "$Id: cupstestppd.c,v 1.22 2003/05/23 15:23:46 mike Exp $".
+ * End of "$Id: cupstestppd.c,v 1.26 2003/11/07 19:34:43 mike Exp $".
  */
