@@ -1,5 +1,5 @@
 /*
- * "$Id: lpinfo.c,v 1.8 2002/12/17 19:00:20 swdev Exp $"
+ * "$Id: lpinfo.c,v 1.9 2003/01/15 04:15:50 mike Exp $"
  *
  *   "lpinfo" command for the Common UNIX Printing System (CUPS).
  *
@@ -70,7 +70,7 @@ main(int  argc,			/* I - Number of command-line arguments */
       switch (argv[i][1])
       {
         case 'E' : /* Encrypt */
-#ifdef HAVE_LIBSSL
+#ifdef HAVE_SSL
 	    cupsSetEncryption(HTTP_ENCRYPT_REQUIRED);
 
 	    if (http)
@@ -78,7 +78,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 #else
             fprintf(stderr, "%s: Sorry, no encryption support compiled in!\n",
 	            argv[0]);
-#endif /* HAVE_LIBSSL */
+#endif /* HAVE_SSL */
 	    break;
 
         case 'l' : /* Show long listing */
@@ -450,5 +450,5 @@ show_models(http_t *http,	/* I - HTTP connection to server */
 
 
 /*
- * End of "$Id: lpinfo.c,v 1.8 2002/12/17 19:00:20 swdev Exp $".
+ * End of "$Id: lpinfo.c,v 1.9 2003/01/15 04:15:50 mike Exp $".
  */
