@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# "$Id: run-stp-tests.sh,v 1.18 2003/04/23 18:38:37 mike Exp $"
+# "$Id: run-stp-tests.sh,v 1.21 2003/11/19 19:56:42 mike Exp $"
 #
 #   Perform the complete set of IPP compliance tests specified in the
 #   CUPS Software Test Plan.
@@ -92,6 +92,39 @@ port=8631
 cwd=`pwd`
 root=`dirname $cwd`
 
+#
+# Make sure that the LPDEST and PRINTER environment variables are
+# not included in the environment that is passed to the tests.  These
+# will usually cause tests to fail erroneously...
+#
+
+typeset +x LPDEST
+typeset +x PRINTER
+
+#
+# See if we want to use valgrind...
+#
+
+echo ""
+echo "This test script can use the Valgrind software from:"
+echo ""
+echo "    http://developer.kde.org/~sewardj/"
+echo ""
+echo "Please enter Y to use Valgrind or N to not use Valgrind:"
+
+read usevalgrind
+
+case "$usevalgrind" in
+	Y* | y*)
+		valgrind="valgrind --logfile=/tmp/$user/log/valgrind --error-limit=no --leak-check=yes --trace-children=yes"
+		echo "Using Valgrind; log files can be found in /tmp/$user/log..."
+		;;
+
+	*)
+		valgrind=""
+		;;
+esac
+
 #
 # Start by creating temporary directories for the tests...
 #
@@ -270,7 +303,7 @@ export HOME
 
 echo "Starting scheduler..."
 
-../scheduler/cupsd -c /tmp/$user/cupsd.conf -f >/tmp/$user/log/debug_log &
+$valgrind ../scheduler/cupsd -c /tmp/$user/cupsd.conf -f >/tmp/$user/log/debug_log &
 cupsd=$!
 
 echo "Scheduler is PID $cupsd; run debugger now if you need to."
@@ -420,6 +453,10 @@ else
 	echo "All tests were successful."
 fi
 
+if test "x$valgrind" != x; then
+	echo "Valgrind lof files can be found in /tmp/$user/log."
+fi
+
 echo ""
 echo "See the following files for details:"
 echo ""
@@ -428,5 +465,5 @@ echo "    $pdffile"
 echo ""
 
 #
-# End of "$Id: run-stp-tests.sh,v 1.18 2003/04/23 18:38:37 mike Exp $"
+# End of "$Id: run-stp-tests.sh,v 1.21 2003/11/19 19:56:42 mike Exp $"
 #
